<?xml version='1.0' standalone='no'?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp '&#160;'> ]>
<xsl:stylesheet
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:gjs="http://www.georgejames.com">

<xsl:include href='gjsForm.xsl'/>

<xsl:template match="Form">
  <xsl:apply-templates select="location"/>
</xsl:template>

<xsl:template match="location">
  <xsl:variable name='readonly'>
    <xsl:choose>
      <xsl:when test='../@method="view"'>
        <xsl:text>1</xsl:text>
      </xsl:when>          
      <xsl:otherwise>
        <xsl:text>0</xsl:text>
      </xsl:otherwise>          
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name='genByKey'>
    <xsl:choose>
      <xsl:when test='../@method="copy"'></xsl:when>
      <xsl:otherwise><xsl:value-of select='@genByKey' /></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name='location'>
    <xsl:choose>
      <xsl:when test='../@method="copy"'></xsl:when>
      <xsl:otherwise><xsl:value-of select='@location' /></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name='revision'>
    <xsl:choose>
      <xsl:when test='../@method="copy"'></xsl:when>
      <xsl:otherwise><xsl:value-of select='@revision' /></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <gjs:form
   title='Location'
   width='770'
   jsFile='vc283.js'
   save='{/Form/@save}'
   close='{/Form/@close}'
   delete='no'
   print='{/Form/@print}'
   help='{/Form/@help}'
   ok='{/Form/@ok}'
   cancel='{/Form/@cancel}'>
     <xsl:if test='../@method!="copy"'>
       <xsl:attribute name='delete'><xsl:value-of select='/Form/@delete' /></xsl:attribute>
     </xsl:if>
     <xsl:choose>
       <xsl:when test='$location!=""'>
         <xsl:attribute name='onload'>frmMain.description.focus()</xsl:attribute>
       </xsl:when>
       <xsl:otherwise>
         <xsl:attribute name='onload'>frmMain.location.focus()</xsl:attribute>
       </xsl:otherwise>
     </xsl:choose>
  
    <gjs:information>
      <xsl:if test='../@method="copy"'>You are creating a copy of the definition of location '<xsl:value-of select='@location'/>'.&nbsp;</xsl:if>
      A location defines mappings to physical addresses that store the documents
      being managed.&nbsp; For example a location may represent a developer's sandbox, a test area, a view of a Deltanji repository, etc.&nbsp;
      <xsl:choose>
        <xsl:when test='$genByKey!=""'>
          This record cannot be amended because it was derived from the <xsl:value-of select='$genByKey'/> template.
        </xsl:when>
        <xsl:when test='$readonly=1'>
          NOTE: Use of this feature is limited on your edition of Deltanji.
        </xsl:when>
        <xsl:otherwise>
          Templates can be defined by using {variable} notation in the key field.
        </xsl:otherwise>
      </xsl:choose>
    </gjs:information>
  
  <div id='divLocation' class='visible' style='min-height: 240px;'>
    <gjs:frame>
    <!-- Set up frame column widths -->
    <gjs:columnWidths>
      <gjs:column width='100'/>
      <gjs:column width='600'/>
    </gjs:columnWidths>
  
    <gjs:fields>
      <gjs:input
       id='location'
       size='20'
       maxlength='40'
       value='{$location}'
       onchange='Form.fnChanged()'>
      <xsl:if test='$location!=""'>
        <xsl:attribute name='readonly'>1</xsl:attribute>
      </xsl:if>
       <label><u>L</u>ocation</label>
       <hint>Name for this location</hint>
      </gjs:input>
  
  
      <gjs:input
       id='description'
       size='60'
       maxlength='200'
       value='{@description}'
       onchange='Form.fnChanged()'
       readonly='{$readonly}'>
       <label>D<u>e</u>scription</label>
       <hint>Description of this location</hint>
      </gjs:input>
  
      <gjs:list1
       id='singleOrMultiVersion'
       width='120'
       value='{@singleOrMultiVersion}'
       onchange='Form.fnChanged()'>
		    <xsl:if test='$readonly="1"'>
		      <xsl:attribute name='disabled'/>  
		    </xsl:if>
        <label>Single /multi-<u>v</u>ersion</label>
        <hint>Specify whether you want to store one or multiple versions of objects in this location.  Note that some storage formats (e.g. M, bin, text) cannot hold multiple versions of objects.</hint>
        <item>
          <label>Single Version</label>
          <value>S</value>
        </item>
        <item>
          <label>Multi-Version</label>
          <value>M</value>
        </item>
      </gjs:list1>
  
  
      <tr>
        <td height='16'></td>
      </tr>
  
      <tr>
        <td>
          <div align='right'>
          <button
            type='button'
						onclick='Form.fnRowUp();Form.fnEventStop(event);'
						title='Move selected row up (click on row icon to select)'>
						<xsl:if test='$readonly="1"'>
							<xsl:attribute name='disabled'/>
						</xsl:if>
            &nbsp;<img src='gjsSortDescending.gif'/>&nbsp;
          </button>&nbsp;&nbsp;<br/>
          <button
            type='button'
						onclick='Form.fnRowDown();Form.fnEventStop(event);'
						title='Move selected row down (click on row icon to select)'>
						<xsl:if test='$readonly="1"'>
							<xsl:attribute name='disabled'/>
						</xsl:if>
            &nbsp;<img src='gjsSortAscending.gif'/>&nbsp;
          </button>&nbsp;&nbsp;<br/>
          </div>
        </td>
        <td>
          <div class='gridTableOuter' style='min-height: 112px;'>
            <table class='formLayoutTable' style='margin-left: 2px'>
                <tr>
                  <gjs:column width='25'/>
                  <gjs:column width='95'/>
                  <gjs:column width='50'/>
                  <gjs:column width='450'/>
                </tr>
                <tr>
                  <td height='30'></td>
                  <gjs:caption><label>Component <u>m</u>ask</label></gjs:caption>
                  <gjs:caption><label>Storage <u>f</u>ormat</label></gjs:caption>
                  <gjs:caption><label>Phys<u>i</u>cal address</label></gjs:caption>
                </tr>            
            </table>
            <div class='gridTableInner' style='height: 112px;' id='divMasks'>
              <table class='formLayoutTable'>
                <tr>
                  <gjs:column width='25'/>
                  <gjs:column width='95'/>
                  <gjs:column width='50'/>
                  <gjs:column width='450'/>
                </tr>
  
                <xsl:apply-templates select='/Form/location/componentMasks'>
									<xsl:with-param name='readonly' select='$readonly'/>
                </xsl:apply-templates>
  
              </table>
            </div>
          </div>
        </td>
      </tr>
  
      <tr>
        <td height='16'></td>
      </tr>
  
      <tr>
        <gjs:caption>
          <label>
            S<u>y</u>stems
          </label>
        </gjs:caption>
        <td>
          <div class='gridTableOuter' style='min-height: 98px; width: 250px;'>
            <table class='formLayoutTable'>
            </table>
            <div class='gridTableInner' style='height: 98px;' id='divSystems'>
              <table class='formLayoutTable'>
                <tr>
                  <gjs:column width='230'/>
                </tr>
  
                <xsl:apply-templates select='/Form/location/systemsInLocation'>
									<xsl:with-param name='readonly' select='$readonly'/>
								</xsl:apply-templates>
  
              </table>
            </div>
          </div>
        </td>
      </tr>
  
      <tr>
        <td height='16'></td>
      </tr>
  
      <gjs:list1
       id='expandFilesets'
       width='100'
       value='{@expandFilesets}'
       onchange='Form.fnChanged()'>
		    <xsl:if test='$readonly="1"'>
		      <xsl:attribute name='disabled'/>  
		    </xsl:if>
        <label><u>B</u>rowse fileset contents?</label>
        <hint>If location uses F or FX storage, should users be able to browse fileset contents?  Note that browsing causes the location's object list to be cleared and reloaded from the chosen file.</hint>
        <item>
          <label>No</label>
          <value>0</value>
        </item>
        <item>
          <label>Yes</label>
          <value>1</value>
        </item>
      </gjs:list1>
  
      <gjs:input
       id='accessCodes'
       size='90'
       maxlength='1000'
       value='{@accessCodes}'
       onchange='Form.fnChanged()'
       readonly='{$readonly}'>
         <label><u>A</u>ccess rights</label>
         <hint>Comma-separated list of access rights.  This controls visibility of the location.</hint>
      </gjs:input>
  
    </gjs:fields>
  
    <gjs:inputHidden id='revision' value='{$revision}'/>
    <gjs:inputHidden id='oldLocation' value='{$location}'/>
  
    </gjs:frame>
  </div>
  </gjs:form>
</xsl:template>


<xsl:template match='/Form/location/componentMasks'>
  <xsl:param name='readonly'/>
  <xsl:variable name='numberOfDisplayRows' select='"0"'/>
  <xsl:variable name='numberOfDataRows' select='count(/Form/location/componentMasks/componentMask)'/>

  <!-- First row is a hidden row that is a template for new rows -->
  <xsl:call-template name='mask'>
		<xsl:with-param name='readonly' select='$readonly'/>
    <xsl:with-param name='display' select='"0"'/>
    <xsl:with-param name='lastRow' select='"1"'/> <!-- sic -->
  </xsl:call-template>

  <!-- Next we render any data rows -->
  <xsl:apply-templates select='/Form/location/componentMasks/componentMask' mode='grid'>
		<xsl:with-param name='readonly' select='$readonly'/>
    <xsl:with-param name='lastRow' select='"0"'/>
  </xsl:apply-templates>

  <!-- Now some empty rows to make sure the display window is full -->
  <xsl:call-template name='empty-rows'>
		<xsl:with-param name='readonly' select='$readonly'/>
    <xsl:with-param name='n' select='number($numberOfDisplayRows)-number($numberOfDataRows)'/>
  </xsl:call-template>

  <!-- Finally the last row which, when filled, will generate a new row from the template -->
  <xsl:call-template name='mask'>
		<xsl:with-param name='readonly' select='$readonly'/>
    <xsl:with-param name='lastRow' select='"1"'/>
  </xsl:call-template>
</xsl:template>


<!-- Generate n empty-rows -->
<xsl:template name='empty-rows'>
  <xsl:param name='readonly'/>
  <xsl:param name='n'/>

  <xsl:if test='number($n) > 0'>
    <xsl:call-template name='mask'>
			<xsl:with-param name='readonly' select='$readonly'/>
      <xsl:with-param name='lastRow' select='"0"'/>
    </xsl:call-template>
    <!-- Call self recursively with n-1 rows -->
    <xsl:call-template name='empty-rows'>
			<xsl:with-param name='readonly' select='$readonly'/>
      <xsl:with-param name='n' select='number($n) - 1'/>
    </xsl:call-template>
  </xsl:if>

</xsl:template>


<xsl:template match='/Form/location/componentMasks/componentMask' name='mask' mode="grid">
  <xsl:param name='readonly'/>
  <xsl:param name='display' select='"1"'/>
  <xsl:param name='lastRow' select='"0"'/>
  <tr 
   title='One or more component masks for mapping components to physical addresses'
   gjsLastRow='{$lastRow}'>
    <xsl:if test='$display="0"'>
      <xsl:attribute name='style'>display: none;</xsl:attribute>  
    </xsl:if>
    <td>
      <img src='vcm_record.gif'
       height='16'
       width='25'
       ondragstart='return false;'>
				<xsl:if test='$readonly!="1"'>
					<xsl:attribute name='onclick'>Form.fnRowSelect(this.parentNode.parentNode,event)</xsl:attribute>
					<xsl:attribute name='title'>To resequence, click here to select the row. Then use up/down buttons or cursor up/down keys.</xsl:attribute>
				</xsl:if>
      </img>
    </td>
    <td>
      <input 
       type='text' 
       size='10'
       maxlength='50' 
       accesskey='M' 
       name='componentMask' 
       value='{@componentMask}' 
       class='input'
       onChange='Form.fnRowChanged(this.parentNode.parentNode)'>
				<xsl:if test='$readonly="1"'>
					<xsl:attribute name='readonly'>1</xsl:attribute>
					<xsl:attribute name='class'>inputDisabled</xsl:attribute>
				</xsl:if>
      </input>
      <input
       type='hidden'
       id='physicalLocation'
       name='physicalLocation'
       value='{@physicalLocation}'/>
    </td>
    <td>
      <table>
        <gjs:list1
         name='storageFormat'
         accesskey='F'
         width='50'
         value='{@storageFormat}'
         onchange='Form.fnChanged()'>
         <xsl:choose>
           <xsl:when test='@physicalLocation or ($readonly="1")'>
             <xsl:attribute name='disabled'/>
             <hint>To change this value, go to Physical Address setup</hint>
           </xsl:when>
           <xsl:otherwise>
             <hint>Select the type of this physical location</hint>
           </xsl:otherwise>
         </xsl:choose>
         <item>
           <label></label>
           <value></value>
         </item>
         <xsl:apply-templates select='/Form/locationTypes/locationType' mode='list1' />
        </gjs:list1>
      </table>
    </td>
    <td>
      <input 
       type='text' 
       size='65'
       maxlength='400' 
       accesskey='I' 
       name='physicalAddress' 
       value='{@physicalAddress}' 
       class='input' 
       onChange='Form.fnChanged()'>
       <xsl:if test='@physicalLocation or ($readonly="1")'>
         <xsl:attribute name='readonly'>1</xsl:attribute>
         <xsl:attribute name='class'>inputDisabled</xsl:attribute>
         <xsl:attribute name='title'>To change this value, go to Physical Address setup</xsl:attribute>
       </xsl:if>
      </input>
    </td>
  </tr>
</xsl:template>


<xsl:template match='/Form/location/systemsInLocation'>
  <xsl:param name='readonly'/>
  <xsl:variable name='numberOfDisplayRows' select='"0"'/>
  <xsl:variable name='numberOfDataRows' select='count(/Form/location/systemsInLocation/system)'/>

  <!-- First row is a hidden row that is a template for new rows -->
  <xsl:call-template name='system'>
    <xsl:with-param name='readonly' select='$readonly'/>
    <xsl:with-param name='display' select='"0"'/>
    <xsl:with-param name='lastRow' select='"1"'/> <!-- sic -->
  </xsl:call-template>

  <!-- Next we render any data rows -->
  <xsl:apply-templates select='/Form/location/systemsInLocation/system' mode='grid'>
    <xsl:with-param name='readonly' select='$readonly'/>
    <xsl:with-param name='lastRow' select='"0"'/>
  </xsl:apply-templates>

  <!-- Now some empty rows to make sure the display window is full -->
  <xsl:call-template name='emptySystemRows'>
    <xsl:with-param name='readonly' select='$readonly'/>
    <xsl:with-param name='n' select='number($numberOfDisplayRows)-number($numberOfDataRows)'/>
  </xsl:call-template>

  <!-- Finally the last row which, when filled, will generate a new row from the template -->
  <xsl:call-template name='system'>
    <xsl:with-param name='readonly' select='$readonly'/>
    <xsl:with-param name='lastRow' select='"1"'/>
  </xsl:call-template>

</xsl:template>


<!-- Generate n empty-rows -->
<xsl:template name="emptySystemRows">
  <xsl:param name='readonly'/>
  <xsl:param name='n'/>

  <xsl:if test="number($n) > 0">
    <xsl:call-template name='system'>
	    <xsl:with-param name='readonly' select='$readonly'/>
      <xsl:with-param name='lastRow' select='"0"'/>
    </xsl:call-template>
    <!-- Call self recursively with n-1 rows -->
    <xsl:call-template name="emptySystemRows">
	    <xsl:with-param name='readonly' select='$readonly'/>
      <xsl:with-param name="n" select="number($n) - 1"/>
    </xsl:call-template>
  </xsl:if>

</xsl:template>

<xsl:template match='/Form/location/systemsInLocation/system' name='system' mode="grid">
	<xsl:param name='readonly'/>
  <xsl:param name='display' select='"1"'/>
  <xsl:param name='lastRow' select='"0"'/>
  <tr 
   title='The systems that belong in this location'
   gjsLastRow='{$lastRow}'>
    <xsl:if test='$display="0"'>
      <xsl:attribute name='style'>display: none;</xsl:attribute>  
    </xsl:if>
    <td>
      <table>
        <gjs:list1
         name='system'
         accesskey='Y'
         width='225'
         value='{@system}'
         onchange='Form.fnRowChanged(this.parentNode.parentNode.parentNode.parentNode.parentNode.parentNode)'>
			    <xsl:if test='$readonly="1"'>
			      <xsl:attribute name='disabled'/>  
			    </xsl:if>
					<hint>Select a system that belongs in this location</hint>
					<item>
						<label></label>
						<value></value>
					</item>
					<xsl:apply-templates select='/Form/systems/system' mode='list1' />
        </gjs:list1>
      </table>
    </td>
  </tr>
</xsl:template>


<!-- Location list boxes -->
<xsl:template match='physicalLocation' mode="list1">
<item>
  <label><xsl:value-of select="@physicalAddress" /></label>
  <value>
    <xsl:value-of select="@physicalLocation" />
  </value>
</item>
</xsl:template>

<!-- Location Types list boxes -->
<xsl:template match='/Form/locationTypes/locationType' mode="list1">
<item>
  <label><xsl:value-of select="@locationType" /></label>
  <value><xsl:value-of select="@locationType" /></value>
</item>
</xsl:template>

<!-- Systems list boxes -->
<xsl:template match='/Form/systems/system' mode="list1">
<item>
  <label><xsl:value-of select="@system" /></label>
  <value><xsl:value-of select="@system" /></value>
</item>
</xsl:template>


</xsl:stylesheet>
