<?xml version='1.0' standalone='no'?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp '&#160;'> ]>
<xsl:stylesheet
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:gjs="http://www.georgejames.com">

<xsl:import href='Selector.xsl'/>
<xsl:include href='gjsForm.xsl'/>

<xsl:template match="Form">
  <xsl:apply-templates select="location"/>
</xsl:template>

<xsl:template match="location">

  <gjs:form
   title='Label Objects at {@location}'
   width='590'
   jsFile='vc284.js'
   save='{/Form/@save}'
   close='{/Form/@close}'
   delete='no'
   print='{/Form/@print}'
   help='{/Form/@help}'
   ok='{/Form/@ok}'
   cancel='{/Form/@cancel}'
   onload='fnLoad()'>
 
    <script src='jquery.xpath.min.js'>
    </script>
  
    <gjs:information>
      A label is a new location that maps to the same storage as its source location.&nbsp;
      By default all objects at the source location '<xsl:value-of select='@location'/>' will be labeled.&nbsp;
      Use the Advanced tab to select which of the source location's current objects will be labeled,
      and to override the message added to the objects' audit records.&nbsp;
      Click OK to create the label and apply it to the chosen objects. 
    </gjs:information>
  
    <br/>
  
    <gjs:tabStrip>
      <gjs:tabStripTab
       id='tabBasic'
       accesskey='B'
       divId='divBasic'>
        <u>B</u>asic
      </gjs:tabStripTab>
      <gjs:tabStripTab
       id='tabAdvanced'
       accesskey='V'
       divId='divAdvanced'>
        Ad<u>v</u>anced
      </gjs:tabStripTab>
    </gjs:tabStrip>

    <div id='divBasic' class='tabPanelVisible' style='min-height: 300px;'>
      <gjs:frame>
        <gjs:columnWidths>
          <gjs:column width='120'/>
          <gjs:column width='340'/>
        </gjs:columnWidths>
    
        <gjs:fields>
          <gjs:input
           id='label'
           accesskey='L'
           size='20'
           maxlength='40'
           value=''
           onchange='Form.fnChanged()'>
           <label><u>L</u>abel</label>
           <hint>Name for the new label.  Cannot be the same as an existing location or label name.</hint>
          </gjs:input>
      
          <gjs:input
           id='description'
           accesskey='E'
           size='60'
           maxlength='200'
           value='Label of {@location} ({@description})'
           onchange='Form.fnChanged()'>
           <label>D<u>e</u>scription</label>
           <hint>Description of this label</hint>
          </gjs:input>
      
          <gjs:input
           id='accessCodes'
           accesskey='R'
           size='60'
           maxlength='1000'
           value=''
           onchange='Form.fnChanged()'>
             <label>Access <u>r</u>ights</label>
             <hint>An optional comma-separated list of access rights.  This controls who can see the label.  If empty then it will be visible to everybody.</hint>
          </gjs:input>
     
          <tr valign='top'>
            <gjs:caption
             for='lclass'
             hint='The new label will be appended to each selected location list'
             accesskey='I'>
              <label>
                L<u>i</u>sts to add label to
              </label>
            </gjs:caption>
            <td>
              <div class='gridTableOuter' style='min-height: 56px; width: 240px;'>
                <table class='formLayoutTable'>
                </table>
                <div class='gridTableInner' style='height: 56px;' id='divLists'>
                  <table class='formLayoutTable'>
                    <tr>
                      <gjs:column width='20'/>
                      <gjs:column width='320'/>
                    </tr>
                    <xsl:apply-templates select="/Form/locationClasses/locationClass" mode='grid'>
                      <xsl:with-param name='disabled' select='count(/Form/locationClasses/locationClass)=1'/>
                    </xsl:apply-templates>
                  </table>
                </div>
              </div>
            </td>
          </tr>
    
        </gjs:fields>
        <gjs:inputHidden id='sourceLocation' value='{@location}'/>
  
      </gjs:frame>
    </div>

  
    <div id='divAdvanced' class='tabPanelHidden' style='min-height: 300px;'>
      <gjs:frame>
        <gjs:columnWidths>
          <gjs:column width='120'/>
          <gjs:column width='340'/>
        </gjs:columnWidths>

        <gjs:fields>
          
          <tr valign='top'>
            <gjs:caption
             for='system'
             hint='Only objects belonging to a selected system will be labeled'
             accesskey='Y'>
              <label>
                S<u>y</u>stems to include
              </label>
            </gjs:caption>
            <td>
              <div class='gridTableOuter' style='min-height: 56px; width: 240px;'>
                <table class='formLayoutTable'>
                </table>
                <div class='gridTableInner' style='height:56px;' id='divSystems'>
                  <table class='formLayoutTable'>
                    <tr>
                      <gjs:column width='20'/>
                      <gjs:column width='320'/>
                    </tr>
                    <xsl:apply-templates select="/Form/location/systemsInLocation/system" mode='grid'>
                      <xsl:with-param name='disabled' select='count(/Form/location/systemsInLocation/system)=1'/>
                    </xsl:apply-templates>
                  </table>
                </div>
              </div>
            </td>
          </tr>
    
          <tr>
            <td height='15'></td>
          </tr>
    	    <tr>
    				<td colspan='4'>
    		
         			<xsl:apply-templates select='/Form/selectors' />
    		
       			</td>
    	    </tr>
      
          <gjs:input
           id='message'
           accesskey='M'
           size='60'
           maxlength='200'
           value='{/Form/route/@message}'
           onchange='Form.fnChanged()'>
           <label>Audit <u>m</u>essage</label>
           <hint>Text for the audit record that will be added to each labeled object. %TO expands as the label name, %FROM as the location the label is being created from.</hint>
          </gjs:input>
        </gjs:fields>
      </gjs:frame>
    </div>
  
    <!-- Leave some space after the panels and before the buttons -->
    <table><tr><td height='6px'></td></tr></table>

  </gjs:form>
</xsl:template>

<xsl:template match='system' mode="grid">
  <xsl:param name='disabled'/>
  <tr 
   class='row'
   title='When checked, label location will accept the system'>
    <xsl:if test='$disabled'>
      <xsl:attribute name='title'>Label location will accept the only eligible system</xsl:attribute>  
    </xsl:if>
    <td style='padding-right: 5px;'>
      <input 
       type='checkbox'
       id='system'
       checked='checked'
       onclick='Form.fnChanged()'
       value='{@system}'>
		    <xsl:if test='$disabled'>
		      <xsl:attribute name='disabled'/>  
		    </xsl:if>
      </input>
    </td>
    <td title='Description of system: {@description}'>
      <xsl:if test='@withdrawn="1"'>
        <xsl:attribute name='style'>text-decoration: line-through;</xsl:attribute>
        <xsl:attribute name='title'>System has been withdrawn from use</xsl:attribute>
      </xsl:if>
      <xsl:value-of select='@system'/>
    </td>
  </tr>
</xsl:template>

<xsl:template match='locationClass' mode="grid">
  <xsl:param name='disabled'/>
  <tr 
   class='row'
   title='When checked, label will be appended to the location list'>
    <xsl:if test='$disabled'>
      <xsl:attribute name='title'>Label will be appended to the only eligible location list</xsl:attribute>  
    </xsl:if>
    <td style='padding-right: 5px;'>
      <input 
       type='checkbox'
       id='lclass'
       checked='checked'
       onclick='Form.fnChanged()'
       value='{@locationClass}'>
		    <xsl:if test='$disabled'>
		      <xsl:attribute name='disabled'/>  
		    </xsl:if>
       </input>
    </td>
    <td title='Description of location class: {@description}'>
      <xsl:value-of select='@locationClass'/>
    </td>
  </tr>
</xsl:template>

<!-- Object selector  -->
<xsl:template match='selectors'>
	<xsl:call-template name='gjs:selector'>
		<xsl:with-param name='chkAll' select='1' />
		<xsl:with-param name='labelIndent' select='0' />
		<xsl:with-param name='labelWidth' select='120' />
		<xsl:with-param name='location' select='/Form/location/@location' />
		<xsl:with-param name='inputSystem' select='"frmMain.system"' />
	</xsl:call-template>
</xsl:template> 

</xsl:stylesheet>
