<?xml version='1.0' encoding='UTF-8'?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp '&#160;'> ]>
<xsl:stylesheet
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:gjs="http://www.georgejames.com">

<!-- Added to make gjsCombo.htc behavior work on IE10 in XSL-generated pages --> 
<!--<xsl:output method="html" encoding="UTF-8"/>-->
<xsl:output
    method="html"
    doctype-public="XSLT-compat"
    omit-xml-declaration="yes"
    encoding="UTF-8"
    indent="yes" />

<xsl:template match="/main">
	<html>
		<xsl:call-template name="head"/>
		<xsl:call-template name="body"/>
	</html>
</xsl:template>
	

<!-- Generate main page head section -->
<xsl:template name="head">
	<head>
		<title>gJax</title>
		
		<!-- Load jQuery -->
		<script src='jquery.min.js'></script>
		
		<!-- Load jQuerySugar, which contains functions that make some jQuery functions look nicer -->
		<script src='jQuerySugar.js'></script>

		<!-- Load jQuery XPath plugin -->
		<script src='jquery.xpath.min.js'></script>
		
		<!-- Load jQueryUI -->
		<link Rel="stylesheet" Href="jquery-ui.css" Type="text/css"/>
		<script src='jquery-ui.min.js'></script>

    <!--  Load the Simple Combobox plugin -->
	  <script src='jquery.easing.min.js'></script>
	  <script src='jquery.scombobox.min.js'></script>
    <link rel='stylesheet' href='jquery.scombobox.min.css' type='text/css' />

		<!-- Load gJax utility package -->
		<link Rel='stylesheet' Href='vc700.css' Type='text/css'/>
		<script src='vc700.js' />
		
		<!-- Load Menu bar -->
		<link Rel="stylesheet" Href="Menubar.css" Type="text/css"/>
		<script src='Menubar.js' />
		
		<!-- Load additional site/app-specific CSS -->
		<xsl:if test="@cssFile">
		  <link Rel='stylesheet' Href='{@cssFile}' Type='text/css'/>
		</xsl:if>
		
		<!-- Load javascript files for Classes -->
		<xsl:apply-templates select="/main/jsFiles/jsFile"/>

		<!-- Set defaults for the calendar controls -->
    <script language='javascript'>
      $(function(){
        $.datepicker.setDefaults({
        <xsl:choose>
          <xsl:when test='user/@locale="US"'>
            dateFormat: 'mm/dd/yy' 
          </xsl:when>
          <xsl:otherwise>
            dateFormat: 'dd/mm/yy' 
          </xsl:otherwise>
        </xsl:choose>
        });
      });
    </script>
		
	</head>
</xsl:template>
	
	
<!-- Load javascript files for Classes -->	
<xsl:template match="/main/jsFiles/jsFile">
	<script src="{@jsFile}"/>
</xsl:template>
	

<!-- Generate body of main page -->
<xsl:template name="body">
	<!-- 
		onload        - login and populate page with locations
		onmousemove   - check whether user is dragging an obv
		onselectstart - disable text selection as this interferes with drag-n-drop
		                If you want text selection to be enabled for any specific element then
		                add onselectstart='window.event.cancelBubble=true;' and style='-moz-user-select: text;'
		                to the specific html element in question.
		ondragstart   - disable IE's built-in drag-n-drop to prevent icons being draggable by default
		                If you want it to be enabled for any specific element then
		                add ondragstart='window.event.cancelBubble=true;' to the specific
		                html element in question.
		onkeypress    - delete key operating on components
		scroll        - we don't want any scroll bars - the divs will have scroll bars
		onresize      - resize all the divs

		Once loaded we can resize all the panels to fit the browser window.  By default they
		all start with a width and height of 0px.
	-->

	<body
	 onload='Main.fnArrangeAll()'
	 onmousemove='fnDragIcon(event)'
	 onmouseup='Main.fnMouseUp()'
	 onselectstart='return false'
	 style='-moz-user-select: none;'
	 ondragstart='return false'
	 scroll='no'>
		<xsl:attribute name="gjsOnLoad">
			<!--	Defer these calls through the frameset handler (see %vc750) because they use the serverLink frame -->
			<xsl:choose>
				<xsl:when test="@connect=0"> <!-- no user identity supplied by client -->
					frameMain.Connect.fnConnectAs()
				</xsl:when>
				<xsl:when test="@connect=1"> <!-- valid user identity supplied by client -->
					frameMain.Connect.fnConnected("<xsl:value-of select="@user"/>")
				</xsl:when>
				<xsl:when test="@connect=2"> <!-- invalid/unknown user identity supplied by client -->
					frameMain.Connect.fnDisconnect(); alert("vc0007 Access denied: User <xsl:value-of select="@user"/> not known")
				</xsl:when>
			</xsl:choose>
		</xsl:attribute>

		<!-- Display empty menu  bar, a real one will be rendered when we know who the user is and what they can do -->
		<div id='divMenu'>
			<ul id='menu'>
				<li>&nbsp;</li>
			</ul>
		</div>
		
		<!-- Main division -->
		<div id='divOuter'>

			<!-- Heading for Folder Panel -->
			<div class='columnHeadingOuter' id='divFolderHeadingOuter'>
				<div class='columnHeadingInner' id='divFolderHeadingInner'>
					<div class='columnHeading' id='divFolderHeading'>
						<table class='layoutTable'>
							<tr>
								<td style='padding-left: 5px;'>
									<div id='divFolderHeadingCaption' align='left'>&nbsp;</div>
								</td>
							</tr>
						</table>
					</div>
					</div>		
				<!-- Close button -->
				<div id='divFolderHeadingClose' class='closeButton' onclick='Main.fnFolderShowHide()' title='Close'>
					<img src='vcmClose.gif' />
				</div>
			</div>

			<!-- Folder Panel -->
			<div id='divFolderTop' />  <!-- Hot area for scrolling this div when drag'n'dropping -->
			<div id='divFolder' />
			<div id='divFolderBottom' />  <!-- Hot area for scrolling this div when drag'n'dropping -->

			<!-- Resize handle for folder panel -->
			<div 
			 id='divFolderResizeHandle'
			 class='widthResizeHandle'
			 onmousedown='Main.fnResizeMouseDown(this)'
			 onmouseup='Main.fnResizeMouseUp(this)' />

			<!--	Toolbar Panel
						Relative positioning allows the toolbars inside to be positioned using
						absolute coordinates that are relative to the top left of this area	-->
			<div id='divSelect' style='position: relative;' />

			<!-- Main Panel -->
			<div id='divMain'>
					<!-- Main Panel Heading -->
					<div class='columnHeadingOuter' id='divMainHeadingOuter'>
						<div class='columnHeadingInner' id='divMainHeadingInner'>
							<div class='columnHeading' id='divMainHead' />
						</div>
					</div>
	
					<!-- Main Panel Body -->
					<div
					 id='divMainBody'
					 onscroll='Main.fnScrollHeading("divMainBody","divMainHead")' /> <!-- scroll heading in sync with body -->

					<!--	Load welcome page into a hidden iframe.  The welcome page should have an onload event that
								copies itself to divMainBody.  Typically this would be:
								onload="parent.document.getElementById('divMainBody').innerHTML=document.getElementById('content').innerHTML;"
								Load it into a hidden iframe and then stuff the content into the main window div
					-->
					<iframe
						id='welcome'
						src='{@welcome}'
						height='0px'
						width='0px'
						frameborder='0px' />
			</div>

			<!-- Resize handle for message panel -->
			<div
			 id='divMessagesResizeHandle'
			 class='heightResizeHandle'
			 onmousedown='Main.fnResizeMouseDown(this)'
			 onmouseup='Main.fnResizeMouseUp(this)' />
		
			<!-- Message Panel Column Heading -->
			<div class='columnHeadingOuter' id='divMessagesHeadingOuter'>
				<div class='columnHeadingInner' id='divMessagesHeadingInner'>
					<div 
					 class='columnHeading' 
					 id='divMessagesHeading' 
					 title='This area displays a log of activity during the current session'>
					</div>
				</div>
				<!-- Close button for div -->
				<div class='closeButton' onclick='Main.fnAuditShowHide()' title='Close'>
					<img src='vcmClose.gif' />
				</div>
			</div>
	
			<!-- Message Panel -->
			<div 
			 id='divMessages' 
			 tabindex='-1' 
			 oncontextmenu='fnContextMenu("popAuditPanel")' 
			 onselectstart='window.event.cancelBubble=true' 
			 onscroll='Main.fnScrollHeading("divMessages","divMessagesHeading")'>
				<div id='divMessagesBody'/>
			</div>
	

			<!--	Loading message.  The contents of this div are copied into the appropriate place
						when a load event is happening.  It is hidden so that it cannot be seen by the user.  -->	
			<div
			 id='divHiddenLoading'
			 style='visibility: hidden;'>
				<table class='layoutTable'>
					<tr>
						<td style='padding-left: 5px; color: blue;'>
							Loading ...
						</td>
					</tr>
				</table>
			</div>
			
			<!--	Drag'n'drop icon.  This div is a container for the drag'n'drop icon.
						It must have nowrap otherwise the drag icon will get wrapped at word breaks
						which messes up the drop-target logic.
						A tabindex of -1 allows the drag icon to have focus (dotted line around it) 
						but not be a tab stop.
			-->
			<div nowrap='nowrap' tabindex='-1' id='divDragIcon' onmouseup='fnDropIcon()'>
				<img src='vcm_folder.gif' />
			</div>

		</div>
	</body>
</xsl:template>

 
</xsl:stylesheet>
