<?xml version='1.0' standalone='no'?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp '&#160;'> ]>
<xsl:stylesheet
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:gjs="http://www.georgejames.com">


<xsl:include href='ServerLink.xsl' />

<!-- MENUBAR
A menu option runs its associated JS function from a 50ms timer started by the onmousedown.
Unless we defer the function invocation via a timer, Firefox tends to return focus to the main window even after
 the function has opened a new window and set focus there.
Apostrophes (i.e. single-quotes) in the option's JS function string are escaped using a recursive template called escape-apos.
-->

<xsl:template match="Menubar">
	<div id="divMenu">
		<ul id="menu">
			<xsl:for-each select="./Menu">
				<xsl:call-template name="menuroot"/>
			</xsl:for-each>
		</ul>
		<xsl:for-each select="./Menu">
			<xsl:call-template name="menupanel"/>
		</xsl:for-each>
		<xsl:for-each select="../Popmenus">
			<xsl:call-template name="popmenus"/>
		</xsl:for-each>
	</div>
</xsl:template>

<xsl:template name="popmenus">
	<div id="divPopmenus">
		<xsl:for-each select="./Popmenu">
			<xsl:call-template name="popmenu"/>
		</xsl:for-each>
	</div>
</xsl:template>

<xsl:template name="menuroot">
	<xsl:variable name="id" select="@id"/>
	<xsl:variable name="accesskeypos" select="@accesskeypos"/>
	<xsl:variable name="disabled" select="@disabled"/>
	<li id="{$id}"
	class="menu-root"
	data-accesskeypos="{$accesskeypos}"
	data-disabled="{$disabled}"
	onclick="Menubar.fnShowMenuPanel('{$id}')">
		<xsl:if test="@disabled = 'true'">
			<xsl:attribute name="class">menu-root ui-state-disabled</xsl:attribute>
    </xsl:if>
		<xsl:value-of select="@caption"/>
	</li>
</xsl:template>

<xsl:template name="menupanel">
	<xsl:variable name="id">
		<xsl:value-of select="@id"/>
		<xsl:text>-panel</xsl:text>
	</xsl:variable>
	<ul class="ui-menu-panel menu-panel" id="{$id}">
		<xsl:for-each select="./MenuOption">
			<xsl:variable name="mid" select="@id"/>
			<xsl:variable name="function">
				<xsl:call-template name="escape-apos">
					<xsl:with-param name="string" select="@function" />
				</xsl:call-template>
			</xsl:variable>
			<xsl:variable name="methodName" select="@methodName"/>
			<xsl:variable name="accesskeypos" select="@accesskeypos"/>
			<xsl:variable name="disabled" select="@disabled"/>
			<xsl:variable name="groupStart" select="@groupStart"/>
			<xsl:if test="$groupStart = '1'">
				<li>-</li>
			</xsl:if>
			<li id="{$mid}"
				data-methodname="{$methodName}"
				data-accesskeypos="{$accesskeypos}"
				data-disabled="{$disabled}">
				<xsl:if test='not(@toolTip="")'>
					<xsl:attribute name='onmouseover'>if (window.status=='') window.status='<xsl:value-of select="@toolTip"/>'</xsl:attribute>
					<xsl:attribute name='onmouseout'>window.status=''</xsl:attribute>
				</xsl:if>
				<xsl:if test='not($function="")'>
					<xsl:attribute name='onmousedown'>setTimeout('<xsl:value-of select="$function"/>',50)</xsl:attribute>
				</xsl:if>
				<xsl:if test="./MenuOption">
					<xsl:attribute name='onclick'>menu_current='<xsl:value-of select="$mid"/>-sub';</xsl:attribute>
				</xsl:if>
				<a><xsl:value-of select="@caption"/></a>
				<xsl:if test="./MenuOption">
					<ul class="ui-menu-panel submenu" id="{$mid}-sub">
						<xsl:for-each select="./MenuOption">
							<xsl:value-of select="caption"/>
								<xsl:call-template name="submenupanel"/>
						</xsl:for-each>
					</ul>
				</xsl:if>
			</li>
		</xsl:for-each>
	</ul>
</xsl:template>

<xsl:template name="submenupanel">
	<xsl:variable name="id" select="@id"/>
	<xsl:variable name="function">
		<xsl:call-template name="escape-apos">
			<xsl:with-param name="string" select="@function" />
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="methodName" select="@methodName"/>
	<xsl:variable name="accesskeypos" select="@accesskeypos"/>
	<xsl:variable name="disabled" select="@disabled"/>
	<li id="{$id}"
		data-methodname="{$methodName}"
		data-accesskeypos="{$accesskeypos}"
		data-disabled="{$disabled}">
		<xsl:if test='not(@toolTip="")'>
			<xsl:attribute name='onmouseover'>if (window.status=='') window.status='<xsl:value-of select="@toolTip"/>'</xsl:attribute>
			<xsl:attribute name='onmouseout'>window.status=''</xsl:attribute>
		</xsl:if>
		<xsl:if test='not($function="")'>
			<xsl:attribute name='onmousedown'>setTimeout('<xsl:value-of select="$function"/>',50)</xsl:attribute>
		</xsl:if>
		<a><xsl:value-of select="@caption"/></a>
	</li>
</xsl:template>

<!-- POPMENUS -->

<xsl:template name="popmenu">
	<xsl:variable name="id" select="@id"/>
	<ul class="ui-menu-panel popmenu-panel" id="{$id}">
		<xsl:for-each select="./MenuOption">
			<xsl:variable name="mid" select="@id"/>
			<xsl:variable name="function">
				<xsl:call-template name="escape-apos">
					<xsl:with-param name="string" select="@function" />
				</xsl:call-template>
			</xsl:variable>
			<xsl:variable name="methodName" select="@methodName"/>
			<xsl:variable name="accesskeypos" select="@accesskeypos"/>
			<xsl:variable name="disabled" select="@disabled"/>
			<xsl:variable name="groupStart" select="@groupStart"/>
			<xsl:if test="$groupStart = '1'">
				<li>-</li>
			</xsl:if>
			<li id="{$mid}"
				data-methodname="{$methodName}"
				data-accesskeypos="{$accesskeypos}"
				data-disabled="{$disabled}">
				<xsl:if test='not(@toolTip="")'>
					<xsl:attribute name='onmouseover'>if (window.status=='') window.status='<xsl:value-of select="@toolTip"/>'</xsl:attribute>
					<xsl:attribute name='onmouseout'>window.status=''</xsl:attribute>
				</xsl:if>
				<xsl:if test='not($function="")'>
					<xsl:attribute name='onmousedown'>setTimeout('<xsl:value-of select="$function"/>',50)</xsl:attribute>
				</xsl:if>
				<a><xsl:value-of select="@caption"/></a>
				<xsl:if test="./MenuOption">
					<ul class="submenu">
						<xsl:for-each select="./MenuOption">
							<xsl:value-of select="caption"/>
								<xsl:call-template name="submenupanel"/>
						</xsl:for-each>
					</ul>
				</xsl:if>
			</li>
		</xsl:for-each>
	</ul>
</xsl:template>

<xsl:template name="escape-apos">
	<xsl:param name="string" />
	<!-- create an $apos variable to make it easier to refer to -->
	<xsl:variable name="apos">'</xsl:variable>
	<xsl:choose>
		<!-- if the string contains an apostrophe... -->
		<xsl:when test="contains($string, $apos)">
			<!-- ... give the value before the apostrophe... -->
			<xsl:value-of select="substring-before($string, $apos)" />
			<!-- ... the escaped apostrophe ... -->
			<xsl:text>\'</xsl:text>
			<!-- ... and the result of applying the template recursively to the string after the apostrophe -->
			<xsl:call-template name="escape-apos">
				<xsl:with-param name="string" select="substring-after($string, $apos)" />
			</xsl:call-template>
		</xsl:when>
		<!-- otherwise... -->
		<xsl:otherwise>
			<!-- ... just give the value of the string -->
			<xsl:value-of select="$string" />
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>
