<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet 
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!-- ServerLink Result Handler
     =========================
     Process the xml result set returned by the remote call and then invoke the result handler.
     Pass an object reference to the div that contains the transformed result set.
-->

<xsl:output
    method="html"
    doctype-public="XSLT-compat"
    omit-xml-declaration="yes"
    indent="yes" />

<xsl:template match="/ServerLink">
  <html>
    <body>
	    <xsl:choose>
	      <xsl:when test='HandlerArgument'>
	      	<xsl:attribute name='style'>font: menu; background-color: buttonface; color: orange;</xsl:attribute>
	      </xsl:when>
	      <xsl:otherwise>
	      	<xsl:attribute name='style'>font: menu; background-color: buttonface; color: red;</xsl:attribute>
	      </xsl:otherwise>
	    </xsl:choose>
      <p>Receiving...</p>
      <!-- display:none used to prevent result being rendered in serverLink frame -->
      <div id='divResultSet' style='display: none;'>
        <xsl:apply-templates />
      </div>
      <p>complete</p>
      <p>Running method <xsl:value-of select='ResultHandler'/>(...)</p>
      <script>
      <xsl:if test='number(@logoutTimer) > 0'>
	setTimeout('parent.frameMain.Connect.fnDisconnect()',<xsl:value-of select='@logoutTimer'/>);
      </xsl:if>
  setTimeout('parent.frameMain.document.body.style.cursor="default"',0);
	parent.serverLink.formServer.session.value="<xsl:value-of select='@sessionId'/>"
	    <xsl:choose>
	      <xsl:when test='HandlerArgument'>
        parent.frameMain.<xsl:value-of select='ResultHandler'/>("<xsl:value-of select='HandlerArgument'/>")
	      </xsl:when>
	      <xsl:otherwise>
        parent.frameMain.<xsl:value-of select='ResultHandler'/>(document)
	      </xsl:otherwise>
	    </xsl:choose>
  parent.serverLink.formServer.session.value='';
      </script>
      <p>complete</p>
    </body>
  </html>
</xsl:template>


<!-- Swallow content of this element -->
<xsl:template match="ResultHandler">
</xsl:template>


<!-- Swallow content of this element -->
<xsl:template match="HandlerArgument">
</xsl:template>


<!-- ServerLink Frameset
     =========================
     Added by frameset^%vc750
     Important to force IE edge mode so Studio doesn't render Deltanji transfer dialog in Compatibility View
-->

<xsl:template match="/ServerLinkFrameset">
	<html>
		<head>
			<meta http-equiv='X-UA-Compatible' content='IE=edge' />
			<link rel='shortcut icon' href='favicon.ico' />
			<title>
				<xsl:value-of select='@siteTitle' />
			</title>
			<xsl:apply-templates select='scriptFile' mode='ServerLink'/>

			<script>
serverUrl='<xsl:value-of select='@url' />';
g_sSession='<xsl:value-of select='@session' />';

<!--
This function used to use a trick so a document could close its window without getting an IE messagebox about the page trying to close the window.
Script in the document invokes it as parent.fnClose()
It worked by first ensuring that the current window was opened from script by invoking window.open('about:blank','_self').
This was sufficient to allow script to close it unquestioned using window.close().
With the P1715 cross-browser project this was no longer necessary for IE, and in fact on Chrome it caused the browser to stop responding,
so it is now a simple window.close() call.
-->
function fnClose() {
	window.close();
}

<!--
This function allows a main document to specify script that must run once all the frames are
ready. To do that, the document sets a gjsOnLoad attribute in its body tag instead of an onload attribute.
A somewhat clunky retry mechanism is used because some browser (Chrome for example) seem to fire the onload on the frameset
before the frames are all ready, particularly when reloading from cache.
-->

// Number of times to sleep and then reattempt access to frameMain.document.body
var g_gjsOnLoad_countdown=10;

function gjsOnLoad() {
  if ( window.console ) {
    if (window.console.log ) {
      window.console.log('gjsOnLoad - countdown='+g_gjsOnLoad_countdown);
    }
  }
	if (!frameMain.document.body) {
  	if (!(g_gjsOnLoad_countdown==0)) {
      // Retry in half a second
      setTimeout(gjsOnLoad,500);
      g_gjsOnLoad_countdown=g_gjsOnLoad_countdown-1;
    }
    return;
  }
	if (typeof(frameMain.document.body.getAttribute('gjsOnLoad'))=='string') {
		eval(frameMain.document.body.getAttribute('gjsOnLoad'));
	}
}
			</script>
		</head>
	
		<!--
		Frameset
		Prevent all hidden frames from being tab-stops, but enable the main frame as a tab stop.
		-->
		<frameset
			id='framesetMain'
			onload='gjsOnLoad();'
			cols='0,1*'
			frameborder='NO'
			border='0'
			tabindex='-1'	
			framespacing='0'
			>
			<frameset rows='270,1*'>
				<frame
					name='serverLink'
					scrolling='AUTO'
					frameborder='1'
					tabindex='-1'
					>
					<xsl:attribute name='src'><xsl:value-of select='@url' />&amp;page=ServerLink.fnHidden</xsl:attribute>
				</frame>

				<!-- The next frame uses a strange src value to prevent IE bleating about nonsecure items when serving over HTTPS -->
				<frame
					name='serverLinkResult'
					scrolling='AUTO'
					frameborder='1'
					tabindex='-1'
					src='javascript:false;'
					/>
			</frameset>
			<frame
				name='frameMain'
				scrolling='NO'
				>
				<xsl:attribute name='src'><xsl:value-of select='@url' />&amp;page=<xsl:value-of select='@frame' /></xsl:attribute>
			</frame>
		</frameset>
	</html>
</xsl:template>

<!-- Hidden input fields on the hidden frame-->

<xsl:template match="scriptFile" mode="ServerLink">
      <script src='{@src}'></script>
</xsl:template>


<!-- ServerLink Hidden Frame
     =========================
     Added by serverLink^%vc750 (ServerLink.fnHidden)
     This frame holds the serverLink communication form
-->

<xsl:template match="/ServerLinkHiddenFrame">
	<html>
		<head>
			<title>gJax ServerLink</title>
			<style>.input {display: block; font: message-box; border-style: inset; border-width: thin;}</style>
			<script src='vc750.js'>
			</script>
		</head>

		<!--
		Server Link communication form
		Use tabindex=-1 to prevent these being seen as tab stops when the user tabs around on the main frame.
		-->
		<body bgcolor='buttonface'>
			<p align='center' style='font: menu; color: blue;' onclick='formServer.submit()'>serverLink (by XSL)</p>
			<form name='formServer' method='POST' action='{@MGWLIB}' target='serverLinkResult'>
				<input type='text' name='page' value='' size='100' class='input' tabindex='-1'/>
				<textarea name='arguments' rows='10' cols='100' class='input' tabindex='-1'></textarea>
				<input type='text' name='resultHandler' value='' size='100' class='input' tabindex='-1'/>
				<input type='text' name='session' value='{@session}' size='100' class='input' tabindex='-1'/>
			
				<xsl:apply-templates select='hiddenField' mode='ServerLink'/>
	
			</form>
		</body>
	</html>
</xsl:template>

<!-- Hidden input fields on the hidden frame-->

<xsl:template match="hiddenField" mode="ServerLink">
      <input type='hidden' name='{@name}' value='{@value}'/>
</xsl:template>

</xsl:stylesheet>
