<?xml version='1.0' standalone='no'?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp '&#160;'> ]>
<xsl:stylesheet
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:gjs="http://www.georgejames.com">

<xsl:include href='gjsForm.xsl'/>

<xsl:template match="Form">
  <xsl:apply-templates select="system"/>
</xsl:template>

<xsl:template match="system">
  <xsl:variable name='readonly'>
    <xsl:choose>
      <xsl:when test='../@method="view"'>
        <xsl:text>1</xsl:text>
      </xsl:when>          
      <xsl:otherwise>
        <xsl:text>0</xsl:text>
      </xsl:otherwise>          
    </xsl:choose>
  </xsl:variable>

<gjs:form
 title='System'
 width='450'
 jsFile='vc261.js'
 onload='frmMain.system.focus();'
 save='{/Form/@save}'
 close='{/Form/@close}'
 delete='{/Form/@delete}'
 print='{/Form/@print}'
 help='{/Form/@help}'
 ok='{/Form/@ok}'
 cancel='{/Form/@cancel}'>

  <gjs:information>
    Systems control which objects belong in which locations.&nbsp; If a system belongs at a location, 
    any objects that belong to the system can be put in the location.
    <xsl:choose>
      <xsl:when test='@genByKey!=""'>
        This record cannot be amended because it was derived from the <xsl:value-of select='@genByKey'/> template.
      </xsl:when>
      <xsl:when test='$readonly=1'>
        NOTE: Use of this feature is limited on your edition of Deltanji.
      </xsl:when>
      <xsl:otherwise>
        Templates can be defined by using {variable} notation in the key field.
      </xsl:otherwise>
    </xsl:choose>
  </gjs:information>

<div id='divSystem' class='visible'>
  <gjs:frame>
  <!-- Set up frame column widths -->
  <gjs:columnWidths>
    <gjs:column width='100'/>
    <gjs:column width='290'/>
  </gjs:columnWidths>

  <gjs:fields>

    <gjs:input
     id='system'
     accesskey='Y'
     size='30'
     maxlength='30'
     value='{@system}'
     onchange='Form.fnChanged()'
     readonly='{$readonly}'>
     <label>S<u>y</u>stem</label>
     <hint>Name that identifies a system</hint>
    </gjs:input>

    <gjs:input
     id='codesc'
     accesskey='E'
     size='40'
     maxlength='40'
     value='{@description}'
     onchange='Form.fnChanged()'
     readonly='{$readonly}'>
     <label>D<u>e</u>scription</label>
     <hint>Description of this system</hint>
    </gjs:input>


    <tr valign="top">
      <gjs:caption for='inSystem' accesskey='L'>
        <label>
          <u>L</u>ocations
        </label>
      </gjs:caption>
      <td>
        <div class='gridTableOuter' style='min-height: 200px; width: 305px;'>
          <table class='formLayoutTable'>
          </table>
          <div class='gridTableInner' style='height: 200px;' id='divLocations'>
            <table class='formLayoutTable'>
              <tr>
                <gjs:column width='20'/>
                <gjs:column width='183'/>
              </tr>
              <xsl:apply-templates select="/Form/system/locationsInSystem/location" mode='grid'>
                <xsl:with-param name='readonly' select='$readonly'/>
                <xsl:with-param name='inSystem' select='"Y"'/>
              </xsl:apply-templates>
              <xsl:if test='$readonly!="1"'>
                <xsl:apply-templates select="/Form/system/locationsNotInSystem/location" mode='grid'>
                  <xsl:with-param name='readonly' select='$readonly'/>
                  <xsl:with-param name='inSystem' select='"N"'/>
                </xsl:apply-templates>
              </xsl:if>
            </table>
          </div>
        </div>
      </td>
    </tr>
    
    <gjs:input
     id='accessCodes'
     size='40'
     maxlength='1000'
     value='{@accessCodes}'
     onchange='Form.fnChanged()'
     readonly='{$readonly}'>
       <label><u>A</u>ccess rights</label>
       <hint>Comma-separated list of access rights.  This controls visibility of the system.  When empty, visibility is unrestricted.</hint>
    </gjs:input>
    
    <gjs:checkbox
     id='withdrawn'
     accesskey='W'
     checked='{@withdrawn}'
		 readonly='{$readonly}'>
      <label><u>W</u>ithdrawn?</label>
      <hint>Check to prevent objects being assigned to this system</hint>
    </gjs:checkbox>

  </gjs:fields>

  <gjs:inputHidden id='revision' value='{@revision}'/>
  <gjs:inputHidden id='oldSystem' value='{@system}'/>

  </gjs:frame>
</div>
</gjs:form>
</xsl:template>

<xsl:template match='location' name='lcode' mode="grid">
	<xsl:param name='readonly'/>
  <xsl:param name='inSystem'/>
  <tr 
   title='Check the box to make this location a member of this system'
   class='row'
   onclick='fnItemSelect(this)'>
    <td style='width: 5%;'>
      <input 
       type='checkbox'
       id='inSystem'
       name='inSystem'
       accesskey='c'
       onclick='Form.fnChanged()'
       gjsLcode='{@location}'>
		    <xsl:if test='$readonly="1"'>
		      <xsl:attribute name='disabled'/>  
		    </xsl:if>
        <xsl:if test='$inSystem="Y"'>
          <xsl:attribute name='checked'>checked</xsl:attribute>
        </xsl:if>
      </input>
    </td>
    <td>
      <xsl:value-of select='@location'/>
    </td>
  </tr>
</xsl:template>


</xsl:stylesheet>
