<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet 
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:exslt="http://exslt.org/common"
 xmlns:msxsl="urn:schemas-microsoft-com:xslt"
 xmlns:gjs="http://www.georgejames.com"
 exclude-result-prefixes="exslt msxsl">

<!-- These templates are included in gjsControls.xsl and gjsForms.xsl -->
<!-- xforms compliantish, except no binding or reference to model -->


<!-- gjs:caption
     Usage:
     <gjs:caption 
      id='gaga'                    Identifies the translation equivalent
      for='gaga'                   Identifies the element pointed to
      hint='Tool tip text'
      readonly='0|1'               Default: 0
      accesskey='X'                Default: Underlined element of label (./label/u)
      dictionary='fileName.xml'    Default: //html/gjs:preferences/@dictionary
      language='xx'                Default: //html/gjs:preferences/@language
      gjaxDictionary='fileName.xml'
      >
       <label><u>X</u>yz</label>   Optional, if dictionary and language specified for the control or the form.
     </gjs:caption>
-->
<xsl:template match='gjs:caption' mode='controls'>

	<xsl:call-template name='gjs:label'>
		<xsl:with-param name='id' select='@for'/>
		<xsl:with-param name='hint' select='@hint'/>
	</xsl:call-template>

</xsl:template>


<!-- gjs:input
     Usage:
     <gjs:input
      id='gaga'
      accesskey='X'                Default: Underlined element of label (./label/u)
      size='99'
      value='{@gaga}'
      onchange='fnGagaChanged()'   Default: Form.fnChanged()
      readonly='0|1'               Default: 0
      row='0|1'                    Default: 1 (generate <tr> element)
      dictionary='fileName.xml'    Default: //html/gjs:preferences/@dictionary
      language='xx'                Default: //html/gjs:preferences/@language
      gjaxDictionary='fileName.xml'
      >
       <label><u>C</u>aption text</label>      Optional, if dictionary and language specified for the control or the form.
       <hint>Tool tip text</hint>              Optional, if dictionary and language specified for the control or the form.
     </gjs:input>
-->
<xsl:template match="gjs:input" mode='controls'>

	<xsl:variable name='hint'>
		<xsl:call-template name='gjs:translateString'>
			<xsl:with-param name='string' select='concat(@id,"_hint")'/>
			<xsl:with-param name='default' select='hint'/>
		</xsl:call-template>
	</xsl:variable>
	
  <xsl:choose>
    <xsl:when test='@row="0"'>
      <xsl:call-template name='gjs:input'>
        <xsl:with-param name='hint' select='$hint'/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <tr>
        <xsl:call-template name='gjs:input'>
          <xsl:with-param name='hint' select='$hint'/>
        </xsl:call-template>
      </tr>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<xsl:template name='gjs:input'>
  <xsl:param name='hint' select='""'/>
	 
  <xsl:call-template name='gjs:label'>
    <xsl:with-param name='hint' select='$hint'/>
  </xsl:call-template>

  <td title='{$hint}'>
    <input 
     class='input'
     type='text' 
     name='{@id}'>
      <xsl:if test='not(@onchange)'>
        <xsl:attribute name='onchange'>Form.fnChanged()</xsl:attribute>
      </xsl:if>
      <xsl:if test='@size'>
        <xsl:attribute name="style">
          width: <xsl:value-of select='@size * 7' />px;
        </xsl:attribute>
      </xsl:if>
      <xsl:apply-templates select="@*" mode='controls' />
    </input>
  </td>
</xsl:template>


<!-- gjs:calendar
     Usage:
     <gjs:calendar
      id='gaga'
      accesskey='X'                Default: Underlined element of label (./label/u)
      gjsInternalValue='{@gaga}'
      onchange='fnGagaChanged()'   Default: Calendar.fnValidate();Form.fnChanged()
      readonly='0|1'               Default: 0
      row='0|1'                    Default: 1 (generate <tr> element)
		  calendar='0|1'               Default: 1
		  validate='0|1'               Default: 1
			gjsLocale='US|EUROPE'        Default: /Form/@locale
      dictionary='fileName.xml'    Default: //html/gjs:preferences/@dictionary
      language='xx'                Default: //html/gjs:preferences/@language
      gjaxDictionary='fileName.xml'
      >
       <label><u>C</u>aption text</label>      Optional, if dictionary and language specified for the control or the form.
       <hint>Tool tip text</hint>              Optional, if dictionary and language specified for the control or the form.
     </gjs:calendar>
-->
<xsl:template match="gjs:calendar" mode='controls'>

	<xsl:variable name='hint'>
		<xsl:call-template name='gjs:translateString'>
			<xsl:with-param name='string' select='concat(@id,"_hint")'/>
			<xsl:with-param name='default' select='hint'/>
		</xsl:call-template>
	</xsl:variable>

  <xsl:choose>
    <xsl:when test='@row="0"'>
      <xsl:call-template name='gjs:calendar'>
        <xsl:with-param name='hint' select='$hint'/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <tr>
        <xsl:call-template name='gjs:calendar'>
          <xsl:with-param name='hint' select='$hint'/>
        </xsl:call-template>
      </tr>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<xsl:template name="gjs:calendar">
  <xsl:param name='hint' select='""'/>
	 
  <xsl:call-template name='gjs:label'>
    <xsl:with-param name='hint' select='$hint'/>
  </xsl:call-template>

  <td title='{$hint}'>
    <input 
      type='text' 
      size='9'
      maxlength='10' 
      id='{@id}' 
      name='{@id}' 
      gjsInternalValue='{@gjsInternalValue}' 
      gjsLocale='{@gjsLocale}'
      class='input'
      onchange='Form.fnChanged()'>
      <!-- When focus gained, start a 0-sec timer that will select all the text. Note that .bind() is used so timer event has the correct 'this' -->
      <xsl:attribute name='onfocus'>setTimeout(function(){this.select()}.bind(this),0)</xsl:attribute>
    <xsl:if test='not(@validate="0")'>
      <xsl:attribute name='onchange'>Calendar.fnValidate(this);Form.fnChanged()</xsl:attribute>
    </xsl:if>
      <xsl:apply-templates select="@*" mode='controls' />
    </input>
  </td>
  <script language='javascript'>
// Set it as a datepicker
$(function() {
  var el;
  el=document.getElementById('<xsl:value-of select='@id' />')
  <xsl:if test='not(@calendar="0") and not(@readonly="1")'>
  $(el).datepicker({
    showOn: 'button',
    buttonImage: 'gjsCalendar.gif',
    buttonImageOnly: true,
    buttonText: 'Display a calendar',
    changeMonth: true,
    changeYear: true,
    closeText: 'Close',
    constrainInput: false,
  <xsl:choose>
    <xsl:when test='@gjsLocale="US"'>
      dateFormat: 'mm/dd/yy', 
    </xsl:when>
    <xsl:when test='@gjsLocale="EUROPE"'>
      dateFormat: 'dd/mm/yy', 
    </xsl:when>
  </xsl:choose>
    selectOtherMonths: true,
    showButtonPanel: true,
    showOtherMonths: true
  });
  </xsl:if>
  
  Calendar.fnSet(el);
});
  </script>
</xsl:template>


<!-- Generic readonly property of any input control -->
<xsl:template match="@readonly" mode='controls'>
  <xsl:if test='.="1"'>
    <xsl:attribute name='readonly'>readonly</xsl:attribute>
    <xsl:attribute name='class'>inputDisabled</xsl:attribute>
  </xsl:if>
</xsl:template>


<!-- Deprecated use gjs:calendar -->
<xsl:template match="gjs:inputDate" mode='controls'>
  <tr title='{hint}'>
    <label 
     for='{@id}' 
     accesskey='{@accesskey}'>
      <td>
        <span class='caption'>
          <xsl:copy-of select='label/node()' />
        </span>
      </td>
    </label>
    <td>
      <!-- Wrap input field and image inside a table to work around an IE formatting bug -->
      <table class='formLayoutTable' width='124'>
        <tr>
          <td>
            <input 
             type='text' 
             size='8'
             maxlength='12' 
             id='{@id}' 
             name='{@id}' 
             value='{@value}' 
             class='input' 
             onfocus='{@onfocus}'
             onchange='{@onchange}'/>
          </td>
        </tr>
      </table>
    </td>
  </tr>
</xsl:template>


<!-- gjs:textarea
     Usage:
     <gjs:textarea
      id='gaga'
      accesskey='X'                Default: Underlined element of label (./label/u)
      rows='99'
			cols='99'
      value='{@gaga}'
      row='0|1'                    Default: 1 (generate <tr> element)
      dictionary='fileName.xml'    Default: //html/gjs:preferences/@dictionary
      language='xx'                Default: //html/gjs:preferences/@language
      gjaxDictionary='fileName.xml'
      >
       <label><u>C</u>aption text</label>      Optional, if dictionary and language specified for the control or the form.
       <hint>Tool tip text</hint>              Optional, if dictionary and language specified for the control or the form.
     </gjs:textarea>
-->
<xsl:template match="gjs:textarea" mode='controls'>

	<xsl:variable name='hint'>
		<xsl:call-template name='gjs:translateString'>
			<xsl:with-param name='string' select='concat(@id,"_hint")'/>
			<xsl:with-param name='default' select='hint'/>
		</xsl:call-template>
	</xsl:variable>

  <xsl:choose>
    <xsl:when test='@row="0"'>
      <xsl:call-template name='gjs:textarea'>
        <xsl:with-param name='hint' select='$hint'/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <tr>
        <xsl:call-template name='gjs:textarea'>
          <xsl:with-param name='hint' select='$hint'/>
        </xsl:call-template>
      </tr>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<xsl:template name="gjs:textarea">
  <xsl:param name='hint' select='""'/>
	 
  <xsl:call-template name='gjs:label'>
    <xsl:with-param name='hint' select='$hint'/>
  </xsl:call-template>

  <td title='{$hint}'>
    <textarea 
      rows='{@rows}'
      cols='{@cols}'
      id='{@id}' 
      name='{@id}' 
      class='input' 
      onfocus='{@onfocus}'
      onchange='{@onchange}'>
      <xsl:if test='@cols'>
        <xsl:attribute name="style">
          width: <xsl:value-of select='@cols * 7' />px;
        </xsl:attribute>
      </xsl:if>
      <xsl:apply-templates select="@*" mode='controls' />
      <xsl:value-of select='@value'/>
    </textarea>
  </td>

</xsl:template>


<xsl:template match="gjs:column" mode='controls'>
      <td width='{@width}' height='0'> </td>
</xsl:template>


<!-- Column heading for sortable table -->
<xsl:template match="gjs:columnHeading" mode='controls'>
  <td>
    <span 
     class='caption'
     onclick='GjsTableSorter.fnSort(this,{@oBody},{@column})'>
      <xsl:value-of select="@caption" />
      <img class='sortIcon' src='gjsSortNormal.gif' />
    </span>
  </td>
</xsl:template>


<!-- xforms compliantish button -->
<!-- gjs:trigger
     Usage:
     <gjs:trigger
      id='gaga'
      onclick='fnGaga()'
      accesskey='X'                Default: Underlined element of label (./label/u)
      dictionary='fileName.xml'    Default: //html/gjs:preferences/@dictionary
      language='xx'                Default: //html/gjs:preferences/@language
      navindex='99'>               Default: 0 (implies form order)
       <label><u>B</u>utton text</label>   Optional, if dictionary and language specified for the control or the form.
       <hint>Tool tip text</hint>          Optional, if dictionary and language specified for the control or the form.
     </gjs:trigger>
-->
<xsl:template match='gjs:trigger' mode='controls'>

	<xsl:variable name='label'>
		<xsl:call-template name='gjs:translateString'>
			<xsl:with-param name='string' select='@id'/>
			<xsl:with-param name='default' select='label'/>
		</xsl:call-template>
	</xsl:variable>

	<xsl:variable name='accesskey'>
		<xsl:call-template name='gjs:translateAccessKey'>
			<xsl:with-param name='string' select='@id'/>
			<xsl:with-param name='default' select='label'/>
			<xsl:with-param name='accessKey' select='@accesskey'/>
		</xsl:call-template>
	</xsl:variable>

	<xsl:variable name='hint'>
		<xsl:call-template name='gjs:translateString'>
			<xsl:with-param name='string' select='concat(@id,"_hint")'/>
			<xsl:with-param name='default' select='hint'/>
		</xsl:call-template>
	</xsl:variable>
	
  <button
	 id='{@id}'
   class='button'
   type='button'
   accesskey='{$accesskey}'
   title='{$hint}'
   tabindex='{@navindex}' >
    <xsl:apply-templates select="@*" mode='controls' />
    <div class='formButtonCaption'>
      <xsl:copy-of select='$label'/>
    </div>
  </button>

</xsl:template>


<!-- xforms checkbox-->
<!-- gjs:checkbox
     Usage:
     <gjs:checkbox
      id='gaga'
      accesskey='X'                Default: Underlined element of label (./label/u)
      dictionary='fileName.xml'    Default: //html/gjs:preferences/@dictionary
      language='xx'                Default: //html/gjs:preferences/@language
      checked='checked' or '1' to set
      readonly='0|1'               Default: 0
      value='1' or '2'
      row='0|1'                    Default: 1
      onclick='fnGaga()'           Default: Form.fnChanged()
       <label><u>C</u>aption text</label>  Optional, if dictionary and language specified for the control or the form.
       <hint>Tool tip text</hint>          Optional, if dictionary and language specified for the control or the form.
     </gjs:checkbox>
-->
<xsl:template match="gjs:checkbox" mode='controls'>

	<xsl:variable name='hint'>
		<xsl:call-template name='gjs:translateString'>
			<xsl:with-param name='string' select='concat(@id,"_hint")'/>
			<xsl:with-param name='default' select='hint'/>
		</xsl:call-template>
	</xsl:variable>

  <xsl:choose>
    <xsl:when test='@row="0"'>
      <xsl:call-template name='gjs:checkbox'>
        <xsl:with-param name='hint' select='$hint'/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <tr>
        <xsl:call-template name='gjs:checkbox'>
          <xsl:with-param name='hint' select='$hint'/>
        </xsl:call-template>
      </tr>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<xsl:template name='gjs:checkbox'>
  <xsl:param name='hint' select='""'/>
	 
  <xsl:call-template name='gjs:label'>
    <xsl:with-param name='hint' select='$hint'/>
  </xsl:call-template>

  <td title='{$hint}'>
    <input
    type='checkbox'
    id='{@id}' 
    name='{@id}' 
    value='{@value}'>
    <xsl:if test='not(@onclick)'>
      <xsl:attribute name='onclick'>Form.fnChanged()</xsl:attribute>
    </xsl:if>
      <xsl:apply-templates select="@*" mode='controls' />
    </input>
  </td>

</xsl:template>


<xsl:template match="gjs:checkbox/@checked" mode='controls'>
  <xsl:if test='.="1" or .="checked"'>
    <xsl:attribute name='checked'>checked</xsl:attribute>
  </xsl:if>
</xsl:template>


<xsl:template match="gjs:checkbox/@readonly" mode='controls'>
  <xsl:if test='.="1"'>
    <xsl:attribute name='disabled'>disabled</xsl:attribute>
    <xsl:attribute name='class'>inputDisabled</xsl:attribute>
  </xsl:if>
</xsl:template>


<!-- xforms radio buttons-->
<!-- gjs:radio
     Usage:
     <gjs:radio
      id='gaga'
      accesskey='X'
      checked='checked' or ''
      value='1' or '2'
			row='0|1'                 Default: 1
      onclick='fnGaga()'
       <label><u>C</u>heckbox caption text</label>
       <hint>Tool tip text</hint>
     </gjs:radio>
-->
<xsl:template match="gjs:radio" mode='controls'>

	<xsl:variable name='hint'>
		<xsl:call-template name='gjs:translateString'>
			<xsl:with-param name='string' select='concat(@id,"_hint")'/>
			<xsl:with-param name='default' select='hint'/>
		</xsl:call-template>
	</xsl:variable>

  <xsl:choose>
    <xsl:when test='@row="0"'>
      <xsl:call-template name='gjs:radio'>
        <xsl:with-param name='hint' select='$hint'/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <tr>
        <xsl:call-template name='gjs:radio'>
          <xsl:with-param name='hint' select='$hint'/>
        </xsl:call-template>
      </tr>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<xsl:template name='gjs:radio'>
  <xsl:param name='hint' select='""'/>
	 
  <xsl:call-template name='gjs:label'>
    <xsl:with-param name='hint' select='$hint'/>
  </xsl:call-template>

  <td title='{$hint}'>
    <input
     type='radio'
     id='{@name}' 
     name='{@name}'
     onClick='{@onclick}'
     value='{@value}'>
			<xsl:apply-templates select="@*" mode='controls' />
    </input>
  </td>

</xsl:template>


<!-- xforms compliantish single select combo box -->
<!-- gjs:select1
     Usage:
     <gjs:select1
      id='gaga'
      accesskey='X'
      maxlength='99'
      value='{@gaga}'
      onchange='fnGagaChanged()'   Default: Form.fnChanged()
      readonly='0|1'               Default: 0
      row='0|1'                    Default: 1 (generate <tr> element)
      >
       <label><u>C</u>aption text</label>
       <hint>Tool tip text</hint>
     </gjs:input>
-->
<xsl:template match="gjs:select1" mode='controls'>

	<xsl:variable name='hint'>
		<xsl:call-template name='gjs:translateString'>
			<xsl:with-param name='string' select='concat(@id,"_hint")'/>
			<xsl:with-param name='default' select='hint'/>
		</xsl:call-template>
	</xsl:variable>
	
  <xsl:choose>
    <xsl:when test='@row="0"'>
      <xsl:call-template name='gjs:select1'>
        <xsl:with-param name='hint' select='$hint'/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <tr>
        <xsl:call-template name='gjs:select1'>
          <xsl:with-param name='hint' select='$hint'/>
        </xsl:call-template>
      </tr>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<xsl:template name="gjs:select1">
  <xsl:param name='hint' select='""'/>
  <xsl:variable name='onchange'>
    <xsl:choose>
      <xsl:when test='@onchange'>
						<xsl:value-of select='@onchange' />
      </xsl:when>
      <xsl:otherwise>
        Form.fnChanged()
      </xsl:otherwise>
    </xsl:choose> 
  </xsl:variable>

  <xsl:call-template name='gjs:label'>
    <xsl:with-param name='id' select='concat(@id,"__textfield")' />
    <xsl:with-param name='hint' select='$hint'/>
  </xsl:call-template>

  <td title='{$hint}' >
    <div style='max-width: {@width};' >
      <select
       style='width: {@width};'
       size='1'
       id='{@id}' 
       name='{@id}' 
       value='{@value}' 
       class='input' 
       gjsMaxLength='{@maxlength}'>
        <xsl:apply-templates select="@*" mode='controls' />
        <xsl:apply-templates select='./item' mode='controls'/>
      </select>
    </div>
    <script language='javascript'>
// Set it as a simple combo
$(function() {
  $('#<xsl:value-of select='@id' />').scombobox({
    highlight: false,
    empty: ($('#<xsl:value-of select='@id' />').attr('value')==''),
    wrap: false,
    loopScrolling: false,
    expandOnFocus: false,
    expandOnFocusWithValue: false,
    invalidAsValue: true,
    fillOnBlur: false,
    fillOnTab: false,
    filterIgnoreCase: false
  });
  $('#<xsl:value-of select='@id' />').css('margin','0px');
  $('#<xsl:value-of select='@id' /> .scombobox-display').css('font-size','100%');
  $('#<xsl:value-of select='@id' /> .scombobox-list p').css('padding','0px 2px 0px 4px');
  $('#<xsl:value-of select='@id' />').scombobox('change',function(){<xsl:value-of select='$onchange' />});
  $(window).resize(function() {
    if ($(window).height()>($('#<xsl:value-of select='@id' />').offset().top * 2)) {
      $('#<xsl:value-of select='@id' /> .scombobox-list').css('bottom','auto');
      $('#<xsl:value-of select='@id' /> .scombobox-list').css('maxHeight',$(window).height()-$('#<xsl:value-of select='@id' />').offset().top-$('#<xsl:value-of select='@id' />').outerHeight(true)-8);
    } else {
      // If more than half way down window, make list pop upwards rather than downwards
      $('#<xsl:value-of select='@id' /> .scombobox-list').css('bottom',$('#<xsl:value-of select='@id' />').css('height'));
      $('#<xsl:value-of select='@id' /> .scombobox-list').css('maxHeight',$('#<xsl:value-of select='@id' />').offset().top-$('#<xsl:value-of select='@id' />').outerHeight(true)-8);
    }
  });
});
    </script>
  </td>

</xsl:template>

<!-- Suppress @onchange attribute for gjs:select1 as this is processed explicitly above -->
<xsl:template match='gjs:select1/@onchange' mode='controls' />



<!-- xforms compliantish single select list box -->
<!-- gjs:list1
     Usage:
     <gjs:list1
      id='gaga'
      accesskey='X'
      width='999'
      value='{@gaga}'
      onchange='fnGagaChanged()'   Default: Form.fnChanged()
      row='0|1'                    Default: 1 (generate <tr> element)
      readonly='0|1'
      >
       <label><u>C</u>aption text</label>
       <hint>Tool tip text</hint>
       <item>
         <label>Option1</label>
         <value>1</value>
       </item>
       <item>
         <label>Option2</label>
         <value>2</value>
       </item>
       ...
       <xsl:apply-templates select='/Form/items/item' mode='list1' />
     </gjs:list1>
-->
<xsl:template match="gjs:list1" mode='controls'>

	<xsl:variable name='hint'>
		<xsl:call-template name='gjs:translateString'>
			<xsl:with-param name='string' select='concat(@id,"_hint")'/>
			<xsl:with-param name='default' select='hint'/>
		</xsl:call-template>
	</xsl:variable>
	
  <xsl:choose>
    <xsl:when test='@row="0"'>
      <xsl:call-template name='gjs:list1'>
        <xsl:with-param name='hint' select='$hint'/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <tr>
        <xsl:call-template name='gjs:list1'>
          <xsl:with-param name='hint' select='$hint'/>
        </xsl:call-template>
      </tr>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<xsl:template name='gjs:list1'>
  <xsl:param name='hint' select='""'/>
	
  <xsl:call-template name='gjs:label'>
    <xsl:with-param name='hint' select='$hint'/>
  </xsl:call-template>

  <td>
    <select
      title='{$hint}' 
      size='1'
      name='{@id}' 
      class='input'>
			<xsl:attribute name='style'>
        min-width: <xsl:value-of select='@width' />px;
        max-width: <xsl:value-of select='@width' />px;
        <xsl:value-of select='@style' />
      </xsl:attribute>
			<xsl:apply-templates select="@*" mode='controls' />
      <xsl:apply-templates select='./item' mode='controls'/>
    </select>
  </td>
</xsl:template>


<xsl:template match="gjs:list1/@readonly" mode='controls'>
  <xsl:if test='.="0"'>
    <xsl:if test='not(@onchange)'>
			<xsl:attribute name='onchange'>Form.fnChanged()</xsl:attribute>
    </xsl:if>
	</xsl:if>
</xsl:template>


<xsl:template match="gjs:list1/@readonly" mode='controls'>
  <xsl:if test='.="1"'>
    <xsl:attribute name='onclick'>this.selectedIndex=-1;</xsl:attribute>
    <xsl:attribute name='class'>inputDisabled</xsl:attribute>
  </xsl:if>
</xsl:template>


<!-- Suppress @style attribute as this is processed explicitly -->
<xsl:template match='gjs:list1/@style' mode='controls' />


<!-- xforms compliantish multi select combo box -->
<!-- gjs:select
     Usage:
     <gjs:select
      id='gaga'
      accesskey='X'
      size='numberOfRows'
      width='999'
      value='{@gaga}'
      >
       <label><u>C</u>aption text</label>
       <hint>Tool tip text</hint>
       <item>
         <label>Option1</label>
         <value>1</value>
       </item>
       <item>
         <label>Option2</label>
         <value>2</value>
       </item>
       ...
       <xsl:apply-templates select='/Form/items/item' mode='list1' />
     </gjs:select>
-->
<xsl:template match="gjs:select" mode='controls'>

	<xsl:variable name='hint'>
		<xsl:call-template name='gjs:translateString'>
			<xsl:with-param name='string' select='concat(@id,"_hint")'/>
			<xsl:with-param name='default' select='hint'/>
		</xsl:call-template>
	</xsl:variable>
	
  <xsl:choose>
    <xsl:when test='@row="0"'>
      <xsl:call-template name='gjs:select'>
        <xsl:with-param name='hint' select='$hint'/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <tr>
        <xsl:call-template name='gjs:select'>
          <xsl:with-param name='hint' select='$hint'/>
        </xsl:call-template>
      </tr>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="gjs:select">
  <xsl:param name='hint' select='""'/>
	 
  <xsl:call-template name='gjs:label'>
    <xsl:with-param name='hint' select='$hint'/>
  </xsl:call-template>

  <td>
    <select
      title='{$hint}'
      name='{@id}' 
      class='input'
      multiple='multiple'>
      <xsl:attribute name='style'>
        min-width: <xsl:value-of select='@width' />px;
        max-width: <xsl:value-of select='@width' />px;
        <xsl:value-of select='@style' />
      </xsl:attribute>
			<xsl:apply-templates select="@*" mode='controls' />
      <xsl:apply-templates select='./item' mode='controls'/>
    </select>
  </td>
</xsl:template>


<!-- Suppress @style attribute as this is processed explicitly -->
<xsl:template match='gjs:select/@style' mode='controls' />


<!-- Suppress @language attribute as this means the user's spoken language in gjax.  
     However in html it's a deprecated attribute that indicates the scripting language.  
     @language='en' would stop an onclick event because the browser wouldn't recognise 
     'en' as a scripting language. --> 
<xsl:template match='@language' mode='controls' />


<xsl:template match="item" mode='controls'>
  <xsl:choose>
    <xsl:when test="(../@value=value) and (string(value))">
      <option value='{value}' selected='selected'>
         <xsl:apply-templates select="@*" mode='controls' />  <!-- for completeness -->
        <xsl:value-of select="label" />
      </option>
    </xsl:when> 
    <xsl:otherwise>
      <option value='{value}'>
        <xsl:apply-templates select="@*" mode='controls'/>
        <xsl:value-of select="label" />
      </option>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<xsl:template match='gjs:grid' mode='controls'>
  <div class='gridTableOuter' style='height: {@height}'>
    <table class='formLayoutTable'>
      <tr>
        <xsl:apply-templates select='gjs:gridColumn' mode='controls'/>
      </tr>
    </table>
    <div class='gridTableInner' style='height: {@height}'>
      <table class='formLayoutTable'>
        <xsl:apply-templates/>
      </table>
    </div>
  </div>
</xsl:template>	


<xsl:template match='gjs:gridColumn' mode='controls'>
  <label
   for='{@id}' 
   accesskey='{@accesskey}'>
    <td width='{@width}'>
      <xsl:choose>
        <xsl:when test='@readonly="1"'>
          <span class='captionDisabled'>
            <xsl:copy-of select='.' />
          </span>
        </xsl:when>
        <xsl:otherwise>
          <span class='caption'>
            <xsl:copy-of select='./node()' />
          </span>
        </xsl:otherwise>
     </xsl:choose>
    </td>
  </label>  
</xsl:template>

	
<xsl:template match='gjs:gridRow' mode='controls'>
  <tr gjsLastRow='?'>
    <xsl:apply-templates/>
  </tr>
</xsl:template>


<xsl:template match='gjs:gridCell' mode='controls'>
  <xsl:variable name='sControl' select='node()'/>

  <!-- Convert the sControl variable from a string to a node-set and process it.
     Use mode="controls" to make this processing distinct from that of the main
     document. -->
  <xsl:choose>
    <xsl:when test="function-available('exslt:node-set')">
      <xsl:apply-templates select="exslt:node-set($sControl)" mode="controls" />
    </xsl:when>
    <xsl:when test="function-available('msxsl:node-set')">
      <xsl:apply-templates select="msxsl:node-set($sControl)" mode="controls" />
    </xsl:when>
  </xsl:choose>
</xsl:template>


<!-- Format a date/time using user's locale -->
<xsl:template name='gjs:formatDateTime'>
  <xsl:param name='locale' select='"US"'/>
  <xsl:param name='date' select='"CcYyMmDdHhNnSs"'/>
    <xsl:if test='$date and $date!=""'> <!-- if not null -->
      <xsl:choose>
        <xsl:when test='$locale="US"'>
          <xsl:value-of select="translate('Mm/Dd/CcYy Hh:Nn:Ss','CcYyMmDdHhNnSs',$date)" /> 
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="translate('Dd/Mm/CcYy Hh:Nn:Ss','CcYyMmDdHhNnSs',$date)" /> 
        </xsl:otherwise>
      </xsl:choose>
    </xsl:if>
</xsl:template>


<!-- Format a date using user's locale -->
<xsl:template name='gjs:formatDate'>
  <xsl:param name='locale' select='"US"'/>
  <xsl:param name='date' select='"CcYyMmDd"'/>
	    <xsl:if test='$date and $date!=""'> <!-- if not null -->
      <xsl:choose>
        <xsl:when test='$locale="US"'>
          <xsl:value-of select="translate('Mm/Dd/CcYy','CcYyMmDd',$date)" /> 
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="translate('Dd/Mm/CcYy','CcYyMmDd',$date)" /> 
        </xsl:otherwise>
      </xsl:choose>
    </xsl:if>
</xsl:template>


<!-- Standard label markup with accesskey.
     NB the $id variable points to the element, the @id attribute identifies the translation equivalent.
     This distinction is important to allow two separate captions to point to the same element.  --> 
<xsl:template name='gjs:label'>
  <xsl:param name='id' select='@id'/>
  <xsl:param name='hint' select='""'/>

	<xsl:variable name='label'>
		<xsl:call-template name='gjs:translateString'>
			<xsl:with-param name='string' select='@id'/>
			<xsl:with-param name='default' select='label'/>
		</xsl:call-template>
	</xsl:variable>

	<xsl:variable name='accesskey'>
		<xsl:call-template name='gjs:translateAccessKey'>
			<xsl:with-param name='string' select='@id'/>
			<xsl:with-param name='default' select='label'/>
			<xsl:with-param name='accessKey' select='@accesskey'/>
		</xsl:call-template>
	</xsl:variable>
  
  <!-- Only add a label if specified.
  This enables embedded gjs:list1 lists in inner tables to be single-cell and to specify an accesskey without confusing Firefox --> 
  <xsl:if test='$label!=""'>
    <td title='{$hint}' style='vertical-align: top; padding-top: 3px;'>
      <label>
        <!-- Only attach an accesskey if label is for a field-->
        <xsl:if test='$id'>
          <xsl:attribute name='for'><xsl:value-of select='$id' /></xsl:attribute>
          <xsl:attribute name='accesskey'><xsl:value-of select='$accesskey' /></xsl:attribute>
        </xsl:if>
        <span class='caption'>
          <xsl:if test='@readonly="1"'>
            <xsl:attribute name='class'>captionDisabled</xsl:attribute>
          </xsl:if>
          <xsl:copy-of select='$label' />
        </span>
      </label>
    </td>
  </xsl:if>

</xsl:template>


<!-- Select the language attribute if present, otherwise from gjs:preferences for the form -->
<xsl:template name='gjs:chooseLanguage'>
	<xsl:choose>
		<xsl:when test='not(@language)'>
			<xsl:value-of select='//html/gjs:preferences/@language'/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select='@language'/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>


<!-- Select the dictionary attribute if present, otherwise use the form's dictionary (in gjs:preferences), failing that use the built-in gjax empty dictionary -->
<xsl:template name='gjs:chooseDictionary'>
	<xsl:choose>
		<xsl:when test='@dictionary'>
			<xsl:value-of select='concat("../",@dictionary)'/>
		</xsl:when>
		<xsl:when test='@gjaxDictionary'>
			<xsl:value-of select='@gjaxDictionary'/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:choose>
				<xsl:when test='//html/gjs:preferences/@dictionary'>
					<xsl:value-of select='concat("../",//html/gjs:preferences/@dictionary)'/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select='"gjsEmptyDictionary.xml"'/>
				</xsl:otherwise>		
			</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>


<xsl:template name='gjs:translateString'>
	<xsl:param name='string' />
	<xsl:param name='default' />

  <!-- Get the user's language and the relevant dictionary file -->
	<xsl:param name='language'>
		<xsl:call-template name='gjs:chooseLanguage' />
	</xsl:param>
	<xsl:param name='dictionary'>
		<xsl:call-template name='gjs:chooseDictionary' />
	</xsl:param>

	<xsl:variable name='source' select='document($dictionary)/dictionary/source[@id=$string]' />

	<!-- TODO: make recursive to handle a list of languages -->
		<xsl:choose>
			<xsl:when test='$source/target[lang($language)]'>
				<xsl:copy-of select='$source/target[lang($language)]/node()' />
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test='$source/target[lang("en")]'>
						<xsl:copy-of select='$source/target[lang("en")]/node()' />
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select='$default' />
					</xsl:otherwise>
				</xsl:choose> 
			</xsl:otherwise>
		</xsl:choose>
</xsl:template>


<xsl:template name='gjs:translateAccessKey'>
	<xsl:param name='string' />
	<xsl:param name='default' />
	<xsl:param name='accessKey' />

		<xsl:choose>
			<xsl:when test='@accesskey'>
				<xsl:value-of select='@accesskey'/>
			</xsl:when>
			<xsl:otherwise>

				<!-- Get the user's language and the relevant dictionary file -->
				<xsl:variable name='language'>
					<xsl:call-template name='gjs:chooseLanguage' />
				</xsl:variable>
				<xsl:variable name='dictionary'>
					<xsl:call-template name='gjs:chooseDictionary' />
				</xsl:variable>

				<xsl:variable name='source' select='document($dictionary)/dictionary/source[@id=$string]' />

				<xsl:choose>
					<xsl:when test='$source/target[lang($language)]'>
						<xsl:value-of select='$source/target[lang($language)]/u' />
					</xsl:when>
					<xsl:otherwise>
						<xsl:choose>
							<xsl:when test='$source/target[lang("en")]'>
								<xsl:value-of select='$source/target[lang("en")]/u' />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select='$default/u' />
							</xsl:otherwise>
						</xsl:choose> 
					</xsl:otherwise>
				</xsl:choose>

			</xsl:otherwise>
		</xsl:choose>
</xsl:template>


</xsl:stylesheet>
