<?xml version='1.0' encoding='UTF-8'?>
<xsl:stylesheet
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:fo="http://www.w3.org/1999/XSL/Format"
 xmlns:gjs="http://www.georgejames.com">

  <!-- gjsReport_Basic.xsl
       This is a report layout template for a basic xsl-fo report.  It includes a standard first
       page and standard page headers and footers.  The content is generated by a call-back to
       the template this is included in.
       
       Usage:
       
          <xsl:import href='gjsReport_Basic.xsl'/>
       
       Override template 'reportTable' to provide your own xsl-fo table body.
       -->


  <xsl:include href='gjsControlsTemplates.xsl'/>


  <xsl:variable name="runDate">
    <xsl:call-template name='gjs:formatDateTime'>
      <xsl:with-param name='locale' select='/report/user/@locale'/>
      <xsl:with-param name='date' select='/report/system/@currentDateTime'/>
    </xsl:call-template>
  </xsl:variable>


  <xsl:template match='report'>
    <fo:root>

      <fo:layout-master-set>
		    <!-- layout for the first page -->
		    <fo:simple-page-master 
		     master-name="first"
		     page-height="21cm"
		     page-width="29.7cm"
		     margin-top="1cm"
		     margin-bottom="2cm"
		     margin-left="1cm"
		     margin-right="1cm">
		      <fo:region-body margin-top="2cm" margin-bottom="1.5cm" />
		      <fo:region-before region-name="xsl-region-before-first" extent="3cm"/>
		      <fo:region-after region-name="xsl-region-after-first" extent="1.5cm"/>
		    </fo:simple-page-master>

		    <!-- layout for the other pages -->
		    <fo:simple-page-master
		     master-name="rest"
		     page-height="21cm"
		     page-width="29.7cm"
		     margin-top="0.5cm"
		     margin-bottom="0.5cm"
		     margin-left="0.5cm"
		     margin-right="0.5cm">
		      <fo:region-body margin-top="1cm" margin-bottom="1cm"/>
		      <fo:region-before extent="1cm"/>
		      <fo:region-after extent="1cm"/>
		    </fo:simple-page-master>

        <fo:page-sequence-master master-name="basicPSM" >
    	    <fo:repeatable-page-master-alternatives>
    		    <fo:conditional-page-master-reference 
    		     master-reference="first"
    			   page-position="first" />
    		    <fo:conditional-page-master-reference 
    		     master-reference="rest"
    			   page-position="rest" />
    		    <!-- recommended fallback procedure -->
    		    <fo:conditional-page-master-reference master-reference="rest" />
    	    </fo:repeatable-page-master-alternatives>
        </fo:page-sequence-master>

	    </fo:layout-master-set>

      <!-- starts actual layout -->
      <fo:page-sequence master-reference="basicPSM">

		    <!-- header -->
		    <fo:static-content flow-name="xsl-region-before">
          <fo:table table-layout="fixed" width="100%">
            <fo:table-column />
            <fo:table-column />
            <fo:table-column />
            <fo:table-body>
              <fo:table-row>
                <fo:table-cell padding="1mm">
                  <fo:block text-align="left" font-size="10pt">
                    <xsl:value-of select="system/@siteTitle"/>
                  </fo:block>
                </fo:table-cell>
                <fo:table-cell padding="1mm">
                  <fo:block text-align="center" font-size="18pt" font-weight="bold">
                    <xsl:value-of select="$title"/>
                  </fo:block>
                </fo:table-cell>
                <fo:table-cell padding="1mm">
                  <fo:block text-align="right" font-size="10pt">
                    <xsl:value-of select="$runDate"/>
                  </fo:block>
                </fo:table-cell>
              </fo:table-row>
            </fo:table-body>
          </fo:table>
		    </fo:static-content>

		    <!-- footer -->
		    <fo:static-content flow-name="xsl-region-after">
          <fo:table table-layout="fixed" width="100%">
            <fo:table-column />
            <fo:table-column />
            <fo:table-column />
            <fo:table-body>
              <fo:table-row>
                <fo:table-cell padding="1mm">
                  <fo:block text-align="left" font-size="10pt">
                    <xsl:value-of select="user/@user"/>
                  </fo:block>
                </fo:table-cell>
                <fo:table-cell padding="1mm">
                  <fo:block text-align="center" font-size="10pt">
                    Page <fo:page-number/>
                  </fo:block>
                </fo:table-cell>
                <fo:table-cell padding="1mm">
                  <fo:block text-align="right" font-size="10pt">
                    <xsl:value-of select="user/@name"/>
                  </fo:block>
                </fo:table-cell>
              </fo:table-row>
            </fo:table-body>
          </fo:table>
		    </fo:static-content>


        <fo:flow flow-name="xsl-region-body">

          <!-- First Page -->
          <fo:table table-layout="fixed" width="100%">
            <fo:table-column/>
            <fo:table-column column-width="50mm"/>
            <fo:table-column column-width="100mm"/>
            <fo:table-column/>
            <fo:table-body>
              <fo:table-row>
                <fo:table-cell/>
                <fo:table-cell padding="1mm" border-width="0.1mm" border-style="solid" border-color="gray" background-color="#F0F0F0">
                  <fo:block color="gray">System</fo:block>
                </fo:table-cell>
                <fo:table-cell padding="1mm" border-width="0.1mm" border-style="solid"  border-color="gray">
                  <fo:block><xsl:value-of select="system/@siteTitle"/></fo:block>
                </fo:table-cell>
                <fo:table-cell/>
              </fo:table-row>
              <fo:table-row>
                <fo:table-cell/>
                <fo:table-cell padding="1mm" border-width="0.1mm" border-style="solid" border-color="gray" background-color="#F0F0F0">
                  <fo:block color="gray">Report name</fo:block>
                </fo:table-cell>
                <fo:table-cell padding="1mm" border-width="0.1mm" border-style="solid" border-color="gray">
                  <fo:block><xsl:value-of select="@title"/></fo:block>
                </fo:table-cell>
                <fo:table-cell/>
              </fo:table-row>
              <fo:table-row>
                <fo:table-cell/>
                <fo:table-cell padding="1mm" border-width="0.1mm" border-style="solid" border-color="gray" background-color="#F0F0F0">
                  <fo:block color="gray">Run date</fo:block>
                </fo:table-cell>
                <fo:table-cell padding="1mm" border-width="0.1mm" border-style="solid" border-color="gray">
                  <fo:block><xsl:value-of select="$runDate"/></fo:block>
                </fo:table-cell>
                <fo:table-cell/>
              </fo:table-row>
              <fo:table-row>
                <fo:table-cell/>
                <fo:table-cell padding="1mm" border-width="0.1mm" border-style="solid" border-color="gray" background-color="#F0F0F0">
                  <fo:block color="gray">Requested by</fo:block>
                </fo:table-cell>
                <fo:table-cell padding="1mm" border-width="0.1mm" border-style="solid" border-color="gray">
                  <fo:block><xsl:value-of select="user/@name"/></fo:block>
                </fo:table-cell>
                <fo:table-cell/>
              </fo:table-row>
            </fo:table-body>
          </fo:table>

          <!-- table start -->
          <fo:table table-layout="fixed" width="100%" border-width="0.1mm" border-style="solid" border-color="gray" break-before="page">
            <xsl:call-template name="reportTable"/>
          </fo:table>
          <!-- table end -->

        </fo:flow>
      </fo:page-sequence>
    </fo:root>

  </xsl:template>
  
  
  <!-- Default output - override this example template with your own -->
  <xsl:template name="reportTable">
    <fo:table-column column-width="50mm"/>
    <fo:table-column column-width="50mm"/>
    <fo:table-column column-width="50mm"/>
    <fo:table-column />
    <fo:table-header>
      <fo:table-row background-color="#F0F0F0">
        <fo:table-cell padding="1mm" border-width="0.1mm" border-style="solid" border-color="gray" padding-left='5mm'>
          <fo:block color="gray">Column 1</fo:block>
        </fo:table-cell>
        <fo:table-cell padding="1mm" border-width="0.1mm" border-style="solid" border-color="gray" padding-end='5mm' text-align="right">
          <fo:block color="gray">Column 2</fo:block>
        </fo:table-cell>
        <fo:table-cell padding="1mm" border-width="0.1mm" border-style="solid" border-color="gray" padding-end='5mm' text-align="right">
          <fo:block color="gray">Column 3</fo:block>
        </fo:table-cell>
        <fo:table-cell padding="1mm" border-width="0.1mm" border-style="solid" border-color="gray" text-align="center">
          <fo:block color="gray">Column 4</fo:block>
        </fo:table-cell>
      </fo:table-row>
    </fo:table-header>
    <fo:table-body>
      <fo:table-row>
        <fo:table-cell padding="1mm" padding-left='5mm'>
          <fo:block>Row 1</fo:block>
        </fo:table-cell>
        <fo:table-cell padding="1mm" padding-end='5mm' text-align="right">
          <fo:block>123.00</fo:block>
        </fo:table-cell>
        <fo:table-cell padding="1mm" padding-end='5mm' text-align="right">
          <fo:block>1</fo:block>
        </fo:table-cell>
        <fo:table-cell padding="1mm" text-align="center">
          <fo:block>centered text</fo:block>
        </fo:table-cell>
      </fo:table-row>
      <fo:table-row>
        <fo:table-cell padding="1mm" padding-left='5mm'>
          <fo:block>Row 2</fo:block>
        </fo:table-cell>
        <fo:table-cell padding="1mm" padding-end='5mm' text-align="right">
          <fo:block>1.00</fo:block>
        </fo:table-cell>
        <fo:table-cell padding="1mm" padding-end='5mm' text-align="right">
          <fo:block>10</fo:block>
        </fo:table-cell>
        <fo:table-cell padding="1mm" text-align="center">
          <fo:block>more centered text</fo:block>
        </fo:table-cell>
      </fo:table-row>
      <fo:table-row>
        <fo:table-cell padding="1mm" padding-left='5mm'>
          <fo:block>Row 3</fo:block>
        </fo:table-cell>
        <fo:table-cell padding="1mm" padding-end='5mm' text-align="right">
          <fo:block>.01</fo:block>
        </fo:table-cell>
        <fo:table-cell padding="1mm" padding-end='5mm' text-align="right">
          <fo:block>100</fo:block>
        </fo:table-cell>
        <fo:table-cell padding="1mm" text-align="center">
          <fo:block>or less</fo:block>
        </fo:table-cell>
      </fo:table-row>
    </fo:table-body>
  </xsl:template>


</xsl:stylesheet>
