#!/usr/bin/perl
#
# Object:    serverLink/cgi
# Component: serverLink.cgi
#
# serverLink.cgi
# Copyright 2000,2001 George James Software Limited
#

# This is what it does:
# 1 Opens a socket connection to an M server
# 2 If the request is a POST then reads STDIN and creates a
#   POST_DATA environment variable (this probably won't work for
#   very large amounts of post data, but its good for 30kbytes).
# 3 Copies all environment variables to the socket in the format:
#       %ENV:environment_variable=value
# 4 Copies the response from the socket to STDOUT
# Anything else should probably be done on the M server

# Usage:
#  serverLink.cgi?ipAddress:port:passPhrase

use strict;
use IO::Socket;

my ($socket, $line, $key, $postData, $peerPort, $peerAddr, $serverLinkAuth, $i);

($peerAddr,$peerPort,$serverLinkAuth) = split(/:/,@ARGV[0],3);


# Create socket object with connection to M server
# If no connection then return an Internal Server Error header.  For security
# reasons do not send any other kind of identifying info.  The web-server will
# log the response which is where you should look for debugging and problem diagnosis.
for ($i=0;$i<=30;$i++) {
  if ($socket = IO::Socket::INET->new(Proto    => "tcp",
        			      PeerAddr => "$peerAddr",
				      PeerPort => "$peerPort")) { 
	print $socket "serverLink.cgi/1.4\n";
	if ($line=<$socket>) {
		if ($line=="r.serverLink/1.4") { last; } }
	}
  elsif ($i==30) {
		print STDOUT "Status: 501 Internal Server Error\015\012";
		print STDOUT "Content-Type: text/html\015\012";
		print STDOUT "\015\012";
		exit;}

  else { 
	if ($i>3) {sleep 1;}
  } 
}


# Stuff the pass-phrase into the ENV hash so that it gets passed to the M server
$ENV{'GJS_SERVERLINK_AUTH'}=$serverLinkAuth;


# Get POST form contents from STDIN and append to the QUERY_STRING
# environment variable.  To the user the Query String will always
# be in the environment variable (nice and simple...too simple).
if ($ENV{'REQUEST_METHOD'} eq 'POST') {
	read(STDIN,$postData,$ENV{'CONTENT_LENGTH'});
	$ENV{'POST_DATA'}=$postData;
}

# Walk ENV hash and print
foreach $key (keys %ENV) {
	print $socket "%ENV:$key=$ENV{$key}\n"};


# Send %END to indicate end of message
print $socket "%END\n";


# Now read the response from the socket and echo it back to the web-server
# which will be waiting on STDOUT.
while ($line = <$socket>) {
	print STDOUT $line;
}

# Done
